@@ -1,85 +1,13 @@
 ##############################################################################
+#
+# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
 # 
-# Zope Public License (ZPL) Version 1.0
-# -------------------------------------
-# 
-# Copyright (c) Digital Creations.  All rights reserved.
-# 
-# This license has been certified as Open Source(tm).
-# 
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions are
-# met:
-# 
-# 1. Redistributions in source code must retain the above copyright
-#    notice, this list of conditions, and the following disclaimer.
-# 
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions, and the following disclaimer in
-#    the documentation and/or other materials provided with the
-#    distribution.
-# 
-# 3. Digital Creations requests that attribution be given to Zope
-#    in any manner possible. Zope includes a "Powered by Zope"
-#    button that is installed by default. While it is not a license
-#    violation to remove this button, it is requested that the
-#    attribution remain. A significant investment has been put
-#    into Zope, and this effort will continue if the Zope community
-#    continues to grow. This is one way to assure that growth.
-# 
-# 4. All advertising materials and documentation mentioning
-#    features derived from or use of this software must display
-#    the following acknowledgement:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    In the event that the product being advertised includes an
-#    intact Zope distribution (with copyright and license included)
-#    then this clause is waived.
-# 
-# 5. Names associated with Zope or Digital Creations must not be used to
-#    endorse or promote products derived from this software without
-#    prior written permission from Digital Creations.
-# 
-# 6. Modified redistributions of any form whatsoever must retain
-#    the following acknowledgment:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    Intact (re-)distributions of any official Zope release do not
-#    require an external acknowledgement.
-# 
-# 7. Modifications are encouraged but must be packaged separately as
-#    patches to official Zope releases.  Distributions that do not
-#    clearly separate the patches from the original work must be clearly
-#    labeled as unofficial distributions.  Modifications which do not
-#    carry the name Zope may be packaged in any form, as long as they
-#    conform to all of the clauses above.
-# 
-# 
-# Disclaimer
-# 
-#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
-#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
-#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
-#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-#   SUCH DAMAGE.
-# 
-# 
-# This software consists of contributions made by Digital Creations and
-# many individuals on behalf of Digital Creations.  Specific
-# attributions are listed in the accompanying credits file.
+# This software is subject to the provisions of the Zope Public License,
+# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
+# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
+# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
+# FOR A PARTICULAR PURPOSE
 # 
 ##############################################################################
 
@@ -147,7 +75,6 @@ from FTPRequest import FTPRequest
 from ZServer import CONNECTION_LIMIT, requestCloseOnExec
 
 from cStringIO import StringIO
-import string
 import os
 from mimetypes import guess_type
 import marshal
@@ -174,7 +101,7 @@ class zope_ftp_channel(ftp_channel):
         path=apply(os.path.join,args)
         path=os.path.normpath(path)
         if os.sep != '/':
-            path=string.replace(path,os.sep,'/')
+            path=path.replace(os.sep,'/')
         return path
     
     # Overriden async_chat methods
@@ -210,7 +137,7 @@ class zope_ftp_channel(ftp_channel):
         # XXX clean this up, maybe with getopts
 
         if len(line) > 1:
-            args = string.split(line[1])
+            args = line[1].split()
         else:
             args =[]
         path_args = []
@@ -220,7 +147,7 @@ class zope_ftp_channel(ftp_channel):
        
         for i in range(len(args)):
             x = args[i]
-            if string.find(x,'*')!=-1 or string.find(x,'?')!=-1:
+            if x.find('*')!=-1 or x.find('?')!=-1:
                 self.globbing = x
                 args[i] = '.'     
 
@@ -318,7 +245,7 @@ class zope_ftp_channel(ftp_channel):
     def cmd_mdtm(self, line):
         'show last modification time of file'
         if len (line) != 2:
-            self.command.not_understood (string.join (line))
+            self.command.not_understood (' '.join(line))
             return
         response=make_response(self, self.mdtm_completion)
         request=FTPRequest(line[1],'MDTM',self,response)
@@ -345,7 +272,7 @@ class zope_ftp_channel(ftp_channel):
     def cmd_size(self, line):
         'return size of file'
         if len (line) != 2:
-            self.command.not_understood (string.join (line))
+            self.command.not_understood (' '.join(line))
             return
         response=make_response(self, self.size_completion)
         request=FTPRequest(line[1],'SIZE',self,response)
@@ -364,7 +291,7 @@ class zope_ftp_channel(ftp_channel):
 
     def cmd_retr(self,line):
         if len(line) < 2:
-            self.command_not_understood (string.join (line))
+            self.command_not_understood (' '.join(line))
             return
         response=make_response(self, self.retr_completion, line[1])
         self._response_producers = response.stdout._producers
@@ -398,7 +325,7 @@ class zope_ftp_channel(ftp_channel):
     def cmd_stor (self, line, mode='wb'):
         'store a file'
         if len (line) < 2:
-            self.command_not_understood (string.join (line))
+            self.command_not_understood (' '.join(line))
             return
         elif self.restart_position:
             restart_position = 0
@@ -442,14 +369,14 @@ class zope_ftp_channel(ftp_channel):
     def cmd_rnfr (self, line):
         'rename from'
         if len (line) != 2:
-            self.command_not_understood (string.join (line))
+            self.command_not_understood (' '.join(line))
         else:
             self.fromfile = line[1]
             self.respond ('350 RNFR command successful.')
 
     def cmd_rnto (self, line):
         if len (line) != 2:
-            self.command_not_understood (string.join (line))
+            self.command_not_understood (' '.join(line))
             return
         pathf,idf=os.path.split(self.fromfile)
         patht,idt=os.path.split(line[1])
@@ -466,7 +393,7 @@ class zope_ftp_channel(ftp_channel):
 
     def cmd_dele(self, line):
         if len (line) != 2:
-            self.command.not_understood (string.join (line))
+            self.command.not_understood (' '.join (line))
             return
         path,id=os.path.split(line[1])
         response=make_response(self, self.dele_completion)
@@ -475,7 +402,7 @@ class zope_ftp_channel(ftp_channel):
         
     def dele_completion(self,response):   
         status=response.getStatus()
-        if status==200 and string.find(response.body,'Not Deletable')==-1:
+        if status==200 and response.body.find('Not Deletable')==-1:
             self.respond('250 DELE command successful.')
         elif status==401:
             self.respond('530 Unauthorized.') 
@@ -484,7 +411,7 @@ class zope_ftp_channel(ftp_channel):
 
     def cmd_mkd(self, line):
         if len (line) != 2:
-            self.command.not_understood (string.join (line))
+            self.command.not_understood (' '.join (line))
             return
         path,id=os.path.split(line[1])
         response=make_response(self, self.mkd_completion)
@@ -506,7 +433,7 @@ class zope_ftp_channel(ftp_channel):
         # XXX should object be checked to see if it's folderish
         #     before we allow it to be RMD'd?
         if len (line) != 2:
-            self.command.not_understood (string.join (line))
+            self.command.not_understood (' '.join (line))
             return
         path,id=os.path.split(line[1])
         response=make_response(self, self.rmd_completion)
@@ -517,7 +444,7 @@ class zope_ftp_channel(ftp_channel):
 
     def rmd_completion(self,response):
         status=response.getStatus()
-        if status==200 and string.find(response.body,'Not Deletable')==-1:
+        if status==200 and response.body.find('Not Deletable')==-1:
             self.respond('250 RMD command successful.')
         elif status==401:
             self.respond('530 Unauthorized.') 
@@ -530,7 +457,7 @@ class zope_ftp_channel(ftp_channel):
             self.userid = line[1]
             self.respond('331 Password required.')
         else:
-            self.command_not_understood (string.join (line))
+            self.command_not_understood (' '.join (line))
 
     def cmd_pass(self, line):
         'specify password'
@@ -539,7 +466,7 @@ class zope_ftp_channel(ftp_channel):
         else:
             pw = line[1]
         self.password=pw
-        i=string.find(self.userid,'@')
+        i=self.userid.find('@')
         if i ==-1:
             if self.server.limiter.check_limit(self):
                 self.respond ('230 Login successful.')
