@@ -1,104 +1,32 @@
 ##############################################################################
+#
+# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
 # 
-# Zope Public License (ZPL) Version 1.0
-# -------------------------------------
-# 
-# Copyright (c) Digital Creations.  All rights reserved.
-# 
-# This license has been certified as Open Source(tm).
-# 
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions are
-# met:
-# 
-# 1. Redistributions in source code must retain the above copyright
-#    notice, this list of conditions, and the following disclaimer.
-# 
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions, and the following disclaimer in
-#    the documentation and/or other materials provided with the
-#    distribution.
-# 
-# 3. Digital Creations requests that attribution be given to Zope
-#    in any manner possible. Zope includes a "Powered by Zope"
-#    button that is installed by default. While it is not a license
-#    violation to remove this button, it is requested that the
-#    attribution remain. A significant investment has been put
-#    into Zope, and this effort will continue if the Zope community
-#    continues to grow. This is one way to assure that growth.
-# 
-# 4. All advertising materials and documentation mentioning
-#    features derived from or use of this software must display
-#    the following acknowledgement:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    In the event that the product being advertised includes an
-#    intact Zope distribution (with copyright and license included)
-#    then this clause is waived.
-# 
-# 5. Names associated with Zope or Digital Creations must not be used to
-#    endorse or promote products derived from this software without
-#    prior written permission from Digital Creations.
-# 
-# 6. Modified redistributions of any form whatsoever must retain
-#    the following acknowledgment:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    Intact (re-)distributions of any official Zope release do not
-#    require an external acknowledgement.
-# 
-# 7. Modifications are encouraged but must be packaged separately as
-#    patches to official Zope releases.  Distributions that do not
-#    clearly separate the patches from the original work must be clearly
-#    labeled as unofficial distributions.  Modifications which do not
-#    carry the name Zope may be packaged in any form, as long as they
-#    conform to all of the clauses above.
-# 
-# 
-# Disclaimer
-# 
-#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
-#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
-#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
-#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-#   SUCH DAMAGE.
-# 
-# 
-# This software consists of contributions made by Digital Creations and
-# many individuals on behalf of Digital Creations.  Specific
-# attributions are listed in the accompanying credits file.
+# This software is subject to the provisions of the Zope Public License,
+# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
+# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
+# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
+# FOR A PARTICULAR PURPOSE
 # 
 ##############################################################################
 """Access control package"""
 
-__version__='$Revision: 1.152.4.2 $'[11:-2]
+__version__='$Revision: 1.166 $'[11:-2]
 
 import Globals, socket, SpecialUsers,re
 import os
 from Globals import DTMLFile, MessageDialog, Persistent, PersistentMapping
-from string import join, strip, split, lower, upper
 from App.Management import Navigation, Tabs
 from Acquisition import Implicit
 from OFS.SimpleItem import Item
 from base64 import decodestring
 from App.ImageFile import ImageFile
-from Role import RoleManager
+from Role import RoleManager, DEFAULTMAXLISTUSERS
 from PermissionRole import _what_not_even_god_should_do, rolesForPermissionOn
-from AuthEncoding import pw_validate
-from AccessControl import getSecurityManager, Unauthorized
+import AuthEncoding
+from AccessControl import getSecurityManager
+from zExceptions import Unauthorized
 from AccessControl.SecurityManagement import newSecurityManager
 from AccessControl.SecurityManagement import noSecurityManager
 from AccessControl.ZopeSecurityPolicy import _noroles
@@ -192,7 +120,7 @@ class BasicUser(Implicit):
     
     def authenticate(self, password, request):
         passwrd=self._getPassword()
-        result = pw_validate(passwrd, password)
+        result = AuthEncoding.pw_validate(passwrd, password)
         domains=self.getDomains()
         if domains:
             return result and domainSpecMatch(domains, request)
@@ -304,7 +232,19 @@ class BasicUser(Implicit):
             break
         return None
 
-    hasRole=allowed
+    def hasRole(self, *args, **kw):
+        """hasRole is an alias for 'allowed' and has been deprecated.
+        
+        Code still using this method should convert to either 'has_role' or
+        'allowed', depending on the intended behaviour.
+
+        """
+        import warnings
+        warnings.warn('BasicUser.hasRole is deprecated, please use '
+            'BasicUser.allowed instead; hasRole was an alias for allowed, but '
+            'you may have ment to use has_role.', DeprecationWarning)
+        self.allowed(*args, **kw)
+
     domains=[]
     
     def has_role(self, roles, object=None):
@@ -372,7 +312,19 @@ class UnrestrictedUser(SpecialUser):
     def allowed(self,parent,roles=None):
         return roles is not _what_not_even_god_should_do
 
-    hasRole=allowed
+    def hasRole(self, *args, **kw):
+        """hasRole is an alias for 'allowed' and has been deprecated.
+        
+        Code still using this method should convert to either 'has_role' or
+        'allowed', depending on the intended behaviour.
+
+        """
+        import warnings
+        warnings.warn('UnrestrictedUser.hasRole is deprecated, please use '
+            'UnrestrictedUser.allowed instead; hasRole was an alias for '
+            'allowed, but you may have ment to use has_role.',
+            DeprecationWarning)
+        self.allowed(*args, **kw)
 
     def has_role(self, roles, object=None): return 1
 
@@ -412,7 +364,19 @@ class NullUnrestrictedUser(SpecialUser):
     def allowed(self, parent, roles=None):
         return 0
 
-    hasRole=allowed
+    def hasRole(self, *args, **kw):
+        """hasRole is an alias for 'allowed' and has been deprecated.
+        
+        Code still using this method should convert to either 'has_role' or
+        'allowed', depending on the intended behaviour.
+
+        """
+        import warnings
+        warnings.warn('NullUnrestrictedUser.hasRole is deprecated, please use '
+            'NullUnrestrictedUser.allowed instead; hasRole was an alias for '
+            'allowed, but you may have ment to use has_role.',
+            DeprecationWarning)
+        self.allowed(*args, **kw)
 
     def has_role(self, roles, object=None):
         return 0
@@ -434,9 +398,9 @@ def readUserAccessFile(filename):
         return None
 
     if line:
-        data = split(strip(line), ':')
+        data = line.strip().split(':')
         remote_user_mode = not data[1]
-        try:    ds = split(data[2], ' ')
+        try:    ds = data[2].split(' ')
         except: ds = []
         return data[0], data[1], ds, remote_user_mode
     else:
@@ -479,11 +443,16 @@ class BasicUserFolder(Implicit, Persistent, Navigation, Tabs, RoleManager,
 
     isPrincipiaFolderish=1
     isAUserFolder=1
+    maxlistusers = DEFAULTMAXLISTUSERS
+
+    encrypt_passwords = 0
 
     manage_options=(
         (
         {'label':'Contents', 'action':'manage_main',
          'help':('OFSP','User-Folder_Contents.stx')},
+        {'label':'Properties', 'action':'manage_userFolderProperties',
+         'help':('OFSP','User-Folder_Properties.stx')},
         )
         +RoleManager.manage_options
         +Item.manage_options
@@ -493,6 +462,7 @@ class BasicUserFolder(Implicit, Persistent, Navigation, Tabs, RoleManager,
         ('Manage users',
          ('manage_users','getUserNames', 'getUser', 'getUsers',
           'getUserById', 'user_names', 'setDomainAuthenticationMode',
+          'userFolderAddUser', 'userFolderEditUser', 'userFolderDelUsers',
           )
          ),
         )
@@ -522,16 +492,55 @@ class BasicUserFolder(Implicit, Persistent, Navigation, Tabs, RoleManager,
            if default is _marker: raise
            return default
 
-    def _doAddUser(self, name, password, roles, domains):
-        """Create a new user"""
+    def _doAddUser(self, name, password, roles, domains, **kw):
+        """Create a new user. This should be implemented by subclasses to
+           do the actual adding of a user. The 'password' will be the
+           original input password, unencrypted. The implementation of this
+           method is responsible for performing any needed encryption."""
         raise NotImplemented
 
-    def _doChangeUser(self, name, password, roles, domains):
-        """Modify an existing user"""
+    def _doChangeUser(self, name, password, roles, domains, **kw):
+        """Modify an existing user. This should be implemented by subclasses 
+           to make the actual changes to a user. The 'password' will be the
+           original input password, unencrypted. The implementation of this
+           method is responsible for performing any needed encryption."""
         raise NotImplemented
 
     def _doDelUsers(self, names):
-        """Delete one or more users"""
+        """Delete one or more users. This should be implemented by subclasses
+           to do the actual deleting of users."""
+        raise NotImplemented
+
+    # As of Zope 2.5, userFolderAddUser, userFolderEditUser and
+    # userFolderDelUsers offer aliases for the the _doAddUser, _doChangeUser
+    # and _doDelUsers methods (with the difference that they can be called
+    # from XML-RPC or untrusted scripting code, given the necessary
+    # permissions).
+    #
+    # Authors of custom user folders don't need to do anything special to
+    # support these - they will just call the appropriate '_' methods that
+    # user folder subclasses already implement.
+    def userFolderAddUser(self, name, password, roles, domains, **kw):
+        """API method for creating a new user object. Note that not all
+           user folder implementations support dynamic creation of user
+           objects."""
+        if hasattr(self, '_doAddUser'):
+            return self._doAddUser(name, password, roles, domains, **kw)
+        raise NotImplemented
+
+    def userFolderEditUser(self, name, password, roles, domains, **kw):
+        """API method for changing user object attributes. Note that not
+           all user folder implementations support changing of user object
+           attributes."""
+        if hasattr(self, '_doChangeUser'):
+            return self._doChangeUser(name, password, roles, domains, **kw)
+        raise NotImplemented
+
+    def userFolderDelUsers(self, names):
+        """API method for deleting one or more user objects. Note that not
+           all user folder implementations support deletion of user objects."""
+        if hasattr(self, '_doDelUsers'):
+            return self._doDelUsers(names)
         raise NotImplemented
 
 
@@ -548,9 +557,9 @@ class BasicUserFolder(Implicit, Persistent, Navigation, Tabs, RoleManager,
 
 
     def identify(self, auth):
-        if auth and lower(auth[:6])=='basic ':
-            try: name, password=tuple(split(decodestring(
-                                      split(auth)[-1]), ':', 1))
+        if auth and auth.lower().startswith('basic '):
+            try: name, password=tuple(decodestring(
+                                      auth.split(' ')[-1]).split(':', 1))
             except:
                 raise 'Bad Request', 'Invalid authentication token'
             return name, password
@@ -750,20 +759,71 @@ class BasicUserFolder(Implicit, Persistent, Navigation, Tabs, RoleManager,
     manage=manage_main=_mainUser
     manage_main._setName('manage_main')
 
-    def domainSpecValidate(self, spec):
+    _userFolderProperties = DTMLFile('dtml/userFolderProps', globals())
+
+    def manage_userFolderProperties(self, REQUEST=None,
+                                    manage_tabs_message=None):
+        """
+        """
+        return self._userFolderProperties(
+            self, REQUEST, manage_tabs_message=manage_tabs_message,
+            management_view='Properties')
+
+    def manage_setUserFolderProperties(self, encrypt_passwords=0,
+                                       update_passwords=0,
+                                       maxlistusers=DEFAULTMAXLISTUSERS,
+                                       REQUEST=None):
+        """
+        Sets the properties of the user folder.
+        """
+        self.encrypt_passwords = not not encrypt_passwords
+        try:
+            self.maxlistusers = int(maxlistusers)
+        except ValueError:
+            self.maxlistusers = DEFAULTMAXLISTUSERS
+        if encrypt_passwords and update_passwords:
+            changed = 0
+            for u in self.getUsers():
+                pw = u._getPassword()
+                if not self._isPasswordEncrypted(pw):
+                    pw = self._encryptPassword(pw)
+                    self._doChangeUser(u.getUserName(), pw, u.getRoles(),
+                                       u.getDomains())
+                    changed = changed + 1
+            if REQUEST is not None:
+                if not changed:
+                    msg = 'All passwords already encrypted.'
+                else:
+                    msg = 'Encrypted %d password(s).' % changed
+                return self.manage_userFolderProperties(
+                    REQUEST, manage_tabs_message=msg)
+            else:
+                return changed
+        else:
+            if REQUEST is not None:
+                return self.manage_userFolderProperties(
+                    REQUEST, manage_tabs_message='Saved changes.')
+
+    def _isPasswordEncrypted(self, pw):
+        return AuthEncoding.is_encrypted(pw)
+
+    def _encryptPassword(self, pw):
+        return AuthEncoding.pw_encrypt(pw, 'SSHA')
+
+
+    def domainSpecValidate(self,spec):
+
         for ob in spec:
-            sz=len(ob)
+
             am = addr_match(ob)
             hm = host_match(ob)
-            if am or hm:
-                if am: am = am.end()
-                else: am = -1
-                if hm: hm = hm.end()
-                else: hm = -1
-                if not ( (am == sz) or (hm == sz) ):
-                    return 0
+
+            if am is None and hm is None:
+                return 0
+
         return 1
 
+
     def _addUser(self,name,password,confirm,roles,domains,REQUEST=None):
         if not name:
             return MessageDialog(
@@ -796,7 +856,7 @@ class BasicUserFolder(Implicit, Persistent, Navigation, Tabs, RoleManager,
                    title  ='Illegal value', 
                    message='Illegal domain specification',
                    action ='manage_main')
-        self._doAddUser(name, password, roles, domains)        
+        self._doAddUser(name, password, roles, domains)
         if REQUEST: return self._mainUser(self, REQUEST)
 
 
@@ -847,7 +907,10 @@ class BasicUserFolder(Implicit, Persistent, Navigation, Tabs, RoleManager,
         if REQUEST: return self._mainUser(self, REQUEST)
 
     def manage_users(self,submit=None,REQUEST=None,RESPONSE=None):
-        """ """
+        """This method handles operations on users for the web based forms
+           of the ZMI. Application code (code that is outside of the forms
+           that implement the UI of a user folder) are encouraged to use
+           manage_std_addUser"""
         if submit=='Add...':
             return self._add_User(self, REQUEST)
 
@@ -959,13 +1022,17 @@ class UserFolder(BasicUserFolder):
         """Return the named user object or None"""
         return self.data.get(name, None)
 
-    def _doAddUser(self, name, password, roles, domains):
+    def _doAddUser(self, name, password, roles, domains, **kw):
         """Create a new user"""
+        if password is not None and self.encrypt_passwords:
+            password = self._encryptPassword(password)
         self.data[name]=User(name,password,roles,domains)
 
-    def _doChangeUser(self, name, password, roles, domains):
+    def _doChangeUser(self, name, password, roles, domains, **kw):
         user=self.data[name]
         if password is not None:
+            if self.encrypt_passwords:
+                password = self._encryptPassword(password)
             user.__=password
         user.roles=roles
         user.domains=domains
@@ -1027,14 +1094,15 @@ def rolejoin(roles, other):
     roles.sort()
     return roles
 
-addr_match=re.compile(r'[\d.]*').match
-host_match=re.compile(r'[-\w.]*').match
+addr_match=re.compile(r'((\d{1,3}\.){1,3}\*)|((\d{1,3}\.){3}\d{1,3})').match
+host_match=re.compile(r'(([\_0-9a-zA-Z\-]*\.)*[0-9a-zA-Z\-]*)').match
+
+
 
 def domainSpecMatch(spec, request):
     host=''
     addr=''
 
-    
     # Fast exit for the match-all case
     if len(spec) == 1 and spec[0] == '*':
         return 1
@@ -1056,14 +1124,14 @@ def domainSpecMatch(spec, request):
         except: pass
 
 
-    _host=split(host, '.')
-    _addr=split(addr, '.')
+    _host=host.split('.')
+    _addr=addr.split('.')
     _hlen=len(_host)
     _alen=len(_addr)
     
     for ob in spec:
         sz=len(ob)
-        _ob=split(ob, '.')
+        _ob=ob.split('.')
         _sz=len(_ob)
 
         mo = addr_match(ob)
