@@ -1,88 +1,17 @@
 /*****************************************************************************
+
+  Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
   
-  Zope Public License (ZPL) Version 1.0
-  -------------------------------------
-  
-  Copyright (c) Digital Creations.  All rights reserved.
-  
-  This license has been certified as Open Source(tm).
-  
-  Redistribution and use in source and binary forms, with or without
-  modification, are permitted provided that the following conditions are
-  met:
-  
-  1. Redistributions in source code must retain the above copyright
-     notice, this list of conditions, and the following disclaimer.
-  
-  2. Redistributions in binary form must reproduce the above copyright
-     notice, this list of conditions, and the following disclaimer in
-     the documentation and/or other materials provided with the
-     distribution.
-  
-  3. Digital Creations requests that attribution be given to Zope
-     in any manner possible. Zope includes a "Powered by Zope"
-     button that is installed by default. While it is not a license
-     violation to remove this button, it is requested that the
-     attribution remain. A significant investment has been put
-     into Zope, and this effort will continue if the Zope community
-     continues to grow. This is one way to assure that growth.
-  
-  4. All advertising materials and documentation mentioning
-     features derived from or use of this software must display
-     the following acknowledgement:
-  
-       "This product includes software developed by Digital Creations
-       for use in the Z Object Publishing Environment
-       (http://www.zope.org/)."
-  
-     In the event that the product being advertised includes an
-     intact Zope distribution (with copyright and license included)
-     then this clause is waived.
-  
-  5. Names associated with Zope or Digital Creations must not be used to
-     endorse or promote products derived from this software without
-     prior written permission from Digital Creations.
-  
-  6. Modified redistributions of any form whatsoever must retain
-     the following acknowledgment:
-  
-       "This product includes software developed by Digital Creations
-       for use in the Z Object Publishing Environment
-       (http://www.zope.org/)."
-  
-     Intact (re-)distributions of any official Zope release do not
-     require an external acknowledgement.
-  
-  7. Modifications are encouraged but must be packaged separately as
-     patches to official Zope releases.  Distributions that do not
-     clearly separate the patches from the original work must be clearly
-     labeled as unofficial distributions.  Modifications which do not
-     carry the name Zope may be packaged in any form, as long as they
-     conform to all of the clauses above.
-  
-  
-  Disclaimer
-  
-    THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
-    EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-    IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-    PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
-    CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-    SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-    LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-    USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND    ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-    OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
-    OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-    SUCH DAMAGE.
-  
-  
-  This software consists of contributions made by Digital Creations and
-  many individuals on behalf of Digital Creations.  Specific
-  attributions are listed in the accompanying credits file.
+  This software is subject to the provisions of the Zope Public License,
+  Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
+  THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
+  WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+  WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
+  FOR A PARTICULAR PURPOSE
   
  ****************************************************************************/
 
-#define BUCKETTEMPLATE_C "$Id: BucketTemplate.c,v 1.17.2.3 2001/11/02 17:26:44 jeremy Exp $\n"
+#define BUCKETTEMPLATE_C "$Id: BucketTemplate.c,v 1.24 2002/01/07 16:49:05 andreasjung Exp $\n"
 
 /*
 ** _bucket_get
@@ -392,7 +321,10 @@ Mapping_update(PyObject *self, PyObject *args)
       else
 	ind = -1;
       Py_DECREF(o);
-      if (ind < 0) goto err;
+      if (ind < 0) {
+        PyErr_SetString(PyExc_TypeError,"Sequence must contain 2-item tuples");
+        goto err;
+        }
     }
 
   Py_XDECREF(items);
@@ -664,7 +596,7 @@ bucket_keys(Bucket *self, PyObject *args)
   for (i=low; i <= high; i++)
     {
       COPY_KEY_TO_OBJECT(key, self->keys[i]);
-      if (PyList_SetItem(r, i, key) < 0) goto err;
+      if (PyList_SetItem(r, i-low , key) < 0) goto err;
     }
 
   PER_ALLOW_DEACTIVATION(self);
@@ -704,7 +636,7 @@ bucket_values(Bucket *self, PyObject *args)
     {
       COPY_VALUE_TO_OBJECT(v, self->values[i]);
       UNLESS (v) goto err;
-      if (PyList_SetItem(r, i, v) < 0) goto err;
+      if (PyList_SetItem(r, i-low, v) < 0) goto err;
     }
 
   PER_ALLOW_DEACTIVATION(self);
@@ -752,7 +684,7 @@ bucket_items(Bucket *self, PyObject *args)
       UNLESS (o) goto err;
       PyTuple_SET_ITEM(item, 1, o);
       
-      if (PyList_SetItem(r, i, item) < 0) goto err;
+      if (PyList_SetItem(r, i-low, item) < 0) goto err;
 
       item = 0;
     }
