@@ -1,85 +1,13 @@
 ##############################################################################
+#
+# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
 # 
-# Zope Public License (ZPL) Version 1.0
-# -------------------------------------
-# 
-# Copyright (c) Digital Creations.  All rights reserved.
-# 
-# This license has been certified as Open Source(tm).
-# 
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions are
-# met:
-# 
-# 1. Redistributions in source code must retain the above copyright
-#    notice, this list of conditions, and the following disclaimer.
-# 
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions, and the following disclaimer in
-#    the documentation and/or other materials provided with the
-#    distribution.
-# 
-# 3. Digital Creations requests that attribution be given to Zope
-#    in any manner possible. Zope includes a "Powered by Zope"
-#    button that is installed by default. While it is not a license
-#    violation to remove this button, it is requested that the
-#    attribution remain. A significant investment has been put
-#    into Zope, and this effort will continue if the Zope community
-#    continues to grow. This is one way to assure that growth.
-# 
-# 4. All advertising materials and documentation mentioning
-#    features derived from or use of this software must display
-#    the following acknowledgement:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    In the event that the product being advertised includes an
-#    intact Zope distribution (with copyright and license included)
-#    then this clause is waived.
-# 
-# 5. Names associated with Zope or Digital Creations must not be used to
-#    endorse or promote products derived from this software without
-#    prior written permission from Digital Creations.
-# 
-# 6. Modified redistributions of any form whatsoever must retain
-#    the following acknowledgment:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    Intact (re-)distributions of any official Zope release do not
-#    require an external acknowledgement.
-# 
-# 7. Modifications are encouraged but must be packaged separately as
-#    patches to official Zope releases.  Distributions that do not
-#    clearly separate the patches from the original work must be clearly
-#    labeled as unofficial distributions.  Modifications which do not
-#    carry the name Zope may be packaged in any form, as long as they
-#    conform to all of the clauses above.
-# 
-# 
-# Disclaimer
-# 
-#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
-#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
-#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
-#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-#   SUCH DAMAGE.
-# 
-# 
-# This software consists of contributions made by Digital Creations and
-# many individuals on behalf of Digital Creations.  Specific
-# attributions are listed in the accompanying credits file.
+# This software is subject to the provisions of the Zope Public License,
+# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
+# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
+# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
+# FOR A PARTICULAR PURPOSE
 # 
 ##############################################################################
 import sys, os, time, random
@@ -135,9 +63,9 @@ class Base:
                 root = self._getRoot()
                 #XXX BTree stuff doesn't implement comparison
                 if hasattr(t, 'items'):
-                    assert list(root[i].items()) == list(t.items())
+                    self.assertEqual(list(root[i].items()) , list(t.items()))
                 else:
-                    assert list(root[i].keys()) == list(t.keys())
+                    self.assertEqual(list(root[i].keys()) , list(t.keys()))
             finally:
                 self._closeDB(root)
                 self._delDB()
@@ -162,9 +90,9 @@ class Base:
                 root[i]._p_changed = None
                 get_transaction().commit()
                 if hasattr(t,'items'):
-                    assert list(root[i].items()) == list(t.items())
+                    self.assertEqual(list(root[i].items()) , list(t.items()))
                 else:
-                    assert list(root[i].keys()) == list(t.keys())
+                    self.assertEqual(list(root[i].keys()) , list(t.keys()))
             finally:
                 self._closeDB(root)
                 self._delDB()
@@ -183,19 +111,19 @@ class MappingBase(Base):
         return self.t[1]
 
     def testGetReturnsDefault(self):
-        assert self.t.get(1) == None
-        assert self.t.get(1, 'foo') == 'foo'
+        self.assertEqual(self.t.get(1) , None)
+        self.assertEqual(self.t.get(1, 'foo') , 'foo')
         
     def testSetItemGetItemWorks(self):
         self.t[1] = 1
         a = self.t[1]
-        assert a == 1, `a`
+        self.assertEqual(a , 1, `a`)
 
     def testReplaceWorks(self):
         self.t[1] = 1
-        assert self.t[1] == 1, self.t[1]
+        self.assertEqual(self.t[1] , 1, self.t[1])
         self.t[1] = 2
-        assert self.t[1] == 2, self.t[1]
+        self.assertEqual(self.t[1] , 2, self.t[1])
 
     def testLen(self):
         added = {}
@@ -205,18 +133,28 @@ class MappingBase(Base):
             self.t[k] = x
             added[k] = x
         addl = added.keys()
-        assert len(self.t) == len(addl), len(self.t)
+        self.assertEqual(len(self.t) , len(addl), len(self.t))
 
     def testHasKeyWorks(self):
         self.t[1] = 1
-        assert self.t.has_key(1)
+        self.assert_(self.t.has_key(1))
 
     def testValuesWorks(self):
         for x in range(100):
             self.t[x] = x*x
         v = self.t.values()
         for i in range(100):
-            assert v[i]==i*i , (i*i,i)
+            self.assertEqual(v[i],i*i , (i*i,i))
+
+    def testValuesWorks1(self):
+
+        for x in range(100):
+            self.t[99-x] = x 
+
+        for x in range(40):
+            lst = list(self.t.values(0+x,99-x))
+            lst.sort()
+            self.assertEqual(lst,range(0+x,99-x+1))
 
             
     def testKeysWorks(self):
@@ -225,11 +163,16 @@ class MappingBase(Base):
         v = self.t.keys()
         i = 0
         for x in v:
-            assert x == i, (x,i)
+            self.assertEqual(x,i)
             i = i + 1
+
+        for x in range(40):
+            lst = self.t.keys(0+x,99-x)
+            self.assertEqual(list(lst),range(0+x,99-x+1))
+
         # BTree items must lie about their lengths, so we convert to list
-        assert len(v) == 100, len(v)
-        #assert len(v) == 100, len(v)
+        self.assertEqual(len(v) , 100, len(v))
+        #self.assertEqual(len(v) , 100, len(v))
 
     def testItemsWorks(self):
         for x in range(100):
@@ -237,8 +180,8 @@ class MappingBase(Base):
         v = self.t.items()
         i = 0
         for x in v:
-            assert x[0] == i, (x[0], i)
-            assert x[1] == i, (x[0], i)
+            self.assertEqual(x[0] , i, (x[0], i))
+            self.assertEqual(x[1] , i, (x[0], i))
             i = i + 1
 
     def testDeleteInvalidKeyRaisesKeyError(self):
@@ -258,12 +201,12 @@ class MappingBase(Base):
         self.t[4] = 150
         del self.t[7]
         t = self.t
-        assert t.maxKey() == 10
-        assert t.maxKey(6) == 6
-        assert t.maxKey(9) == 8
-        assert t.minKey() == 1
-        assert t.minKey(3) == 3
-        assert t.minKey(9) == 10
+        self.assertEqual(t.maxKey() , 10)
+        self.assertEqual(t.maxKey(6) , 6)
+        self.assertEqual(t.maxKey(9) , 8)
+        self.assertEqual(t.minKey() , 1)
+        self.assertEqual(t.minKey(3) , 3)
+        self.assertEqual(t.minKey(9) , 10)
 
     def testClear(self):
         r = range(100)
@@ -272,7 +215,7 @@ class MappingBase(Base):
             self.t[rnd] = 0
         self.t.clear()
         diff = lsubtract(list(self.t.keys()), [])
-        assert diff == [], diff
+        self.assertEqual(diff , [], diff)
 
     def testUpdate(self):
         "mapping update"
@@ -287,21 +230,21 @@ class MappingBase(Base):
         items.sort()
 
         self.t.update(d)
-        assert list(self.t.items()) == items
+        self.assertEqual(list(self.t.items()) , items)
 
         self.t.clear()
-        assert list(self.t.items()) == []
+        self.assertEqual(list(self.t.items()) , [])
 
         self.t.update(l)
-        assert list(self.t.items()) == items
+        self.assertEqual(list(self.t.items()) , items)
 
     def testEmptyRangeSearches(self):
         t=self.t
         t.update([(1,1),(5,5),(9,9)])
-        assert list(t.keys(-6,-4))==[], list(t.keys(-6,-4))
-        assert list(t.keys(2,4))==[], list(t.keys(2,4))
-        assert list(t.keys(6,8))==[], list(t.keys(6,8))
-        assert list(t.keys(10,12))==[], list(t.keys(10,12))
+        self.assertEqual(list(t.keys(-6,-4)),[], list(t.keys(-6,-4)))
+        self.assertEqual(list(t.keys(2,4)),[], list(t.keys(2,4)))
+        self.assertEqual(list(t.keys(6,8)),[], list(t.keys(6,8)))
+        self.assertEqual(list(t.keys(10,12)),[], list(t.keys(10,12)))
         
 
 class NormalSetTests(Base):
@@ -315,17 +258,17 @@ class NormalSetTests(Base):
 
     def testInsertReturnsValue(self):
         t = self.t
-        assert t.insert(5) == 1
+        self.assertEqual(t.insert(5) , 1)
 
     def testDuplicateInsert(self):
         t = self.t
         t.insert(5)
-        assert t.insert(5) == 0
+        self.assertEqual(t.insert(5) , 0)
         
     def testInsert(self):
         t = self.t
         t.insert(1)
-        assert t.has_key(1)
+        self.assert_(t.has_key(1))
 
     def testBigInsert(self):
         t = self.t
@@ -333,7 +276,7 @@ class NormalSetTests(Base):
         for x in r:
             t.insert(x)
         for x in r:
-            assert t.has_key(x)
+            self.assert_(t.has_key(x))
 
     def testRemoveSucceeds(self):
         t = self.t
@@ -349,14 +292,14 @@ class NormalSetTests(Base):
 
     def testHasKeyFails(self):
         t = self.t
-        assert not t.has_key(1)
+        self.assert_(not t.has_key(1))
 
     def testKeys(self):
         t = self.t
         r = xrange(1000)
         for x in r: t.insert(x)
         diff = lsubtract(t.keys(), r)
-        assert diff == [], diff
+        self.assertEqual(diff , [], diff)
 
     def testClear(self):
         t = self.t
@@ -364,7 +307,7 @@ class NormalSetTests(Base):
         for x in r: t.insert(x)
         t.clear()
         diff = lsubtract(t.keys(), [])
-        assert diff == [], diff
+        self.assertEqual(diff , [], diff)
 
     def testMaxKeyMinKey(self):
         t = self.t
@@ -376,12 +319,12 @@ class NormalSetTests(Base):
         t.insert(10)
         t.insert(6)
         t.insert(4)
-        assert t.maxKey() == 10
-        assert t.maxKey(6) == 6
-        assert t.maxKey(9) == 8
-        assert t.minKey() == 1
-        assert t.minKey(3) == 3
-        assert t.minKey(9) == 10
+        self.assertEqual(t.maxKey() , 10)
+        self.assertEqual(t.maxKey(6) , 6)
+        self.assertEqual(t.maxKey(9) , 8)
+        self.assertEqual(t.minKey() , 1)
+        self.assertEqual(t.minKey(3) , 3)
+        self.assertEqual(t.minKey(9) , 10)
 
     def testUpdate(self):
         "mapping update"
@@ -396,29 +339,29 @@ class NormalSetTests(Base):
         items.sort()
 
         self.t.update(l)
-        assert list(self.t.keys()) == items
+        self.assertEqual(list(self.t.keys()) , items)
 
     def testEmptyRangeSearches(self):
         t=self.t
         t.update([1,5,9])
-        assert list(t.keys(-6,-4))==[], list(t.keys(-6,-4))
-        assert list(t.keys(2,4))==[], list(t.keys(2,4))
-        assert list(t.keys(6,8))==[], list(t.keys(6,8))
-        assert list(t.keys(10,12))==[], list(t.keys(10,12))
+        self.assertEqual(list(t.keys(-6,-4)),[], list(t.keys(-6,-4)))
+        self.assertEqual(list(t.keys(2,4)),[], list(t.keys(2,4)))
+        self.assertEqual(list(t.keys(6,8)),[], list(t.keys(6,8)))
+        self.assertEqual(list(t.keys(10,12)),[], list(t.keys(10,12)))
 
 class ExtendedSetTests(NormalSetTests):
     def testLen(self):
         t = self.t
         r = xrange(10000)
         for x in r: t.insert(x)
-        assert len(t) == 10000, len(t)
+        self.assertEqual(len(t) , 10000, len(t))
 
     def testGetItem(self):
         t = self.t
         r = xrange(10000)
         for x in r: t.insert(x)
         for x in r:
-            assert t[x] == x
+            self.assertEqual(t[x] , x)
         
 class BucketTests(MappingBase):
     """ Tests common to all buckets """
@@ -436,7 +379,7 @@ class BTreeTests(MappingBase):
         self.t[4] = 99
         del self.t[4]
         diff = lsubtract(self.t.keys(), [1,2,3,5,6,10])
-        assert diff == [], diff
+        self.assertEqual(diff , [], diff)
 
     def testDeleteOneChildWorks(self):
         self.t[5] = 6
@@ -448,7 +391,7 @@ class BTreeTests(MappingBase):
         self.t[4] = 99
         del self.t[3]
         diff = lsubtract(self.t.keys(), [1,2,4,5,6,10])
-        assert diff == [], diff
+        self.assertEqual(diff , [], diff)
 
     def testDeleteTwoChildrenNoInorderSuccessorWorks(self):
         self.t[5] = 6
@@ -460,7 +403,7 @@ class BTreeTests(MappingBase):
         self.t[4] = 99
         del self.t[2]
         diff = lsubtract(self.t.keys(), [1,3,4,5,6,10])
-        assert diff == [], diff
+        self.assertEqual(diff , [], diff)
         
     def testDeleteTwoChildrenInorderSuccessorWorks(self):
         """ 7, 3, 8, 1, 5, 10, 6, 4 -- del 3 """
@@ -474,7 +417,7 @@ class BTreeTests(MappingBase):
         self.t[4] = 150
         del self.t[3]
         diff = lsubtract(self.t.keys(), [1,4,5,6,7,8,10])
-        assert diff == [], diff
+        self.assertEqual(diff , [], diff)
 
     def testDeleteRootWorks(self):
         """ 7, 3, 8, 1, 5, 10, 6, 4 -- del 7 """
@@ -488,7 +431,7 @@ class BTreeTests(MappingBase):
         self.t[4] = 150
         del self.t[7]
         diff = lsubtract(self.t.keys(), [1,3,4,5,6,8,10])
-        assert diff == [], diff
+        self.assertEqual(diff , [], diff)
 
     def testRandomNonOverlappingInserts(self):
         added = {}
@@ -501,7 +444,7 @@ class BTreeTests(MappingBase):
         addl = added.keys()
         addl.sort()
         diff = lsubtract(list(self.t.keys()), addl)
-        assert diff == [], (diff, addl, list(self.t.keys()))
+        self.assertEqual(diff , [], (diff, addl, list(self.t.keys())))
 
     def testRandomOverlappingInserts(self):
         added = {}
@@ -513,7 +456,7 @@ class BTreeTests(MappingBase):
         addl = added.keys()
         addl.sort()
         diff = lsubtract(self.t.keys(), addl)
-        assert diff == [], diff
+        self.assertEqual(diff , [], diff)
 
     def testRandomDeletes(self):
         r = range(1000)
@@ -534,7 +477,7 @@ class BTreeTests(MappingBase):
         for x in deleted:
             if self.t.has_key(x):
                 badones.append(x)
-        assert badones == [], (badones, added, deleted)
+        self.assertEqual(badones , [], (badones, added, deleted))
 
     def testTargetedDeletes(self):
         r = range(1000)
@@ -546,16 +489,16 @@ class BTreeTests(MappingBase):
                 del self.t[x]
             except KeyError:
                 pass
-        assert realseq(self.t.keys()) == [], realseq(self.t.keys())
+        self.assertEqual(realseq(self.t.keys()) , [], realseq(self.t.keys()))
         
     def testPathologicalRightBranching(self):
         r = range(1000)
         for x in r:
             self.t[x] = 1
-        assert realseq(self.t.keys()) == r, realseq(self.t.keys())
+        self.assertEqual(realseq(self.t.keys()) , r, realseq(self.t.keys()))
         for x in r:
             del self.t[x]
-        assert realseq(self.t.keys()) == [], realseq(self.t.keys())
+        self.assertEqual(realseq(self.t.keys()) , [], realseq(self.t.keys()))
 
     def testPathologicalLeftBranching(self):
         r = range(1000)
@@ -563,11 +506,11 @@ class BTreeTests(MappingBase):
         revr.reverse()
         for x in revr:
             self.t[x] = 1
-        assert realseq(self.t.keys()) == r, realseq(self.t.keys())
+        self.assertEqual(realseq(self.t.keys()) , r, realseq(self.t.keys()))
 
         for x in revr:
             del self.t[x]
-        assert realseq(self.t.keys()) == [], realseq(self.t.keys())
+        self.assertEqual(realseq(self.t.keys()) , [], realseq(self.t.keys()))
 
     def testSuccessorChildParentRewriteExerciseCase(self):
         add_order = [
@@ -613,14 +556,14 @@ class BTreeTests(MappingBase):
         for x in delete_order:
             try: del self.t[x]
             except KeyError:
-                if self.t.has_key(x): assert 1==2,"failed to delete %s" % x
+                if self.t.has_key(x): self.assertEqual(1,2,"failed to delete %s" % x)
 
     def testRangeSearchAfterSequentialInsert(self):
         r = range(100)
         for x in r:
             self.t[x] = 0
         diff = lsubtract(list(self.t.keys(0, 100)), r)
-        assert diff == [], diff
+        self.assertEqual(diff , [], diff)
 
     def testRangeSearchAfterRandomInsert(self):
         r = range(100)
@@ -630,14 +573,14 @@ class BTreeTests(MappingBase):
             self.t[rnd] = 0
             a[rnd] = 0
         diff = lsubtract(list(self.t.keys(0, 100)), a.keys())
-        assert diff == [], diff
+        self.assertEqual(diff , [], diff)
 
     def testInsertMethod(self):
         t = self.t
         t[0] = 1
-        assert t.insert(0, 1) == 0
-        assert t.insert(1, 1) == 1
-        assert lsubtract(list(t.keys()), [0,1]) == []
+        self.assertEqual(t.insert(0, 1) , 0)
+        self.assertEqual(t.insert(1, 1) , 1)
+        self.assertEqual(lsubtract(list(t.keys()), [0,1]) , [])
 
 ## BTree tests
 
@@ -807,6 +750,8 @@ def test_suite():
 
     return alltests
 
+
+
 ## utility functions
 
 def lsubtract(l1, l2):
@@ -819,3 +764,10 @@ def lsubtract(l1, l2):
 def realseq(itemsob):
     return map(lambda x: x, itemsob)
 
+
+def main():
+    TextTestRunner().run(test_suite())
+
+if __name__ == '__main__':
+    main()
+
