@@ -1,94 +1,21 @@
 ##############################################################################
+#
+# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
 # 
-# Zope Public License (ZPL) Version 1.0
-# -------------------------------------
-# 
-# Copyright (c) Digital Creations.  All rights reserved.
-# 
-# This license has been certified as Open Source(tm).
-# 
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions are
-# met:
-# 
-# 1. Redistributions in source code must retain the above copyright
-#    notice, this list of conditions, and the following disclaimer.
-# 
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions, and the following disclaimer in
-#    the documentation and/or other materials provided with the
-#    distribution.
-# 
-# 3. Digital Creations requests that attribution be given to Zope
-#    in any manner possible. Zope includes a "Powered by Zope"
-#    button that is installed by default. While it is not a license
-#    violation to remove this button, it is requested that the
-#    attribution remain. A significant investment has been put
-#    into Zope, and this effort will continue if the Zope community
-#    continues to grow. This is one way to assure that growth.
-# 
-# 4. All advertising materials and documentation mentioning
-#    features derived from or use of this software must display
-#    the following acknowledgement:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    In the event that the product being advertised includes an
-#    intact Zope distribution (with copyright and license included)
-#    then this clause is waived.
-# 
-# 5. Names associated with Zope or Digital Creations must not be used to
-#    endorse or promote products derived from this software without
-#    prior written permission from Digital Creations.
-# 
-# 6. Modified redistributions of any form whatsoever must retain
-#    the following acknowledgment:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    Intact (re-)distributions of any official Zope release do not
-#    require an external acknowledgement.
-# 
-# 7. Modifications are encouraged but must be packaged separately as
-#    patches to official Zope releases.  Distributions that do not
-#    clearly separate the patches from the original work must be clearly
-#    labeled as unofficial distributions.  Modifications which do not
-#    carry the name Zope may be packaged in any form, as long as they
-#    conform to all of the clauses above.
-# 
-# 
-# Disclaimer
-# 
-#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
-#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
-#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
-#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-#   SUCH DAMAGE.
-# 
-# 
-# This software consists of contributions made by Digital Creations and
-# many individuals on behalf of Digital Creations.  Specific
-# attributions are listed in the accompanying credits file.
+# This software is subject to the provisions of the Zope Public License,
+# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
+# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
+# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
+# FOR A PARTICULAR PURPOSE
 # 
 ##############################################################################
 """Encapsulation of date/time values"""
 
-__version__='$Revision: 1.68.2.2 $'[11:-2]
+__version__='$Revision: 1.74 $'[11:-2]
 
 
 import re,sys, os, math,  DateTimeZone
-from string import strip,split,upper,lower,atoi,atof,find,join
 from time import time, gmtime, localtime, asctime
 from time import timezone, strftime
 from time import daylight, timezone, altzone
@@ -107,11 +34,8 @@ to_month=tm[yr%4==0 and (yr%100!=0 or yr%400==0)][mo]
 EPOCH  =(to_year+to_month+dy+(hr/24.0+mn/1440.0+sc/86400.0))*86400
 jd1901 =2415385L
 
-
 numericTimeZoneMatch=re.compile(r'[+-][0-9][0-9][0-9][0-9]').match #TS
 
-
-
 class _timezone:
     def __init__(self,data):
         self.name,self.timect,self.typect, \
@@ -149,7 +73,7 @@ class _timezone:
     def info(self,t=None):
         idx=self.index(t)[0]
         zs =self.az[self.tinfo[idx][2]:]
-        return self.tinfo[idx][0],self.tinfo[idx][1],zs[:find(zs,'\000')]
+        return self.tinfo[idx][0],self.tinfo[idx][1],zs[:zs.find('\000')]
 
 
 
@@ -304,7 +228,7 @@ class _cache:
         self._d,self._zidx={},self._zmap.keys()
 
     def __getitem__(self,k):
-        try:   n=self._zmap[lower(k)]
+        try:   n=self._zmap[k.lower()]
         except KeyError:
             if numericTimeZoneMatch(k) == None:
                 raise 'DateTimeError','Unrecognized timezone: %s' % k
@@ -323,7 +247,7 @@ def _findLocalTimeZoneName(isDST):
     try:
         # Get the name of the current time zone depending
         # on DST.
-        _localzone = _cache._zmap[lower(tzname[isDST])]
+        _localzone = _cache._zmap[tzname[isDST].lower()]
     except:
         try:
             # Generate a GMT-offset zone name.
@@ -338,7 +262,7 @@ def _findLocalTimeZoneName(isDST):
             else: minorOffset = 0
             m=majorOffset >= 0 and '+' or ''
             lz='%s%0.02d%0.02d' % (m, majorOffset, minorOffset)
-            _localzone = _cache._zmap[lower('GMT%s' % lz)]
+            _localzone = _cache._zmap[('GMT%s' % lz).lower()]
         except:
             _localzone = ''
     return _localzone
@@ -437,7 +361,7 @@ def _tzoffset(tz, t):
         return DateTime._tzinfo[tz].info(t)[0]
     except:
         if numericTimeZoneMatch(tz) is not None:
-            return atoi(tz[1:3])*3600+atoi(tz[3:5])*60
+            return -int(tz[1:3])*3600-int(tz[3:5])*60
         else:
             return 0 # ??
 
@@ -700,9 +624,9 @@ class DateTime:
             if arg=='':
                 raise self.SyntaxError, arg
             
-            if type(arg) in [StringType,UnicodeType] and lower(arg) in self._tzinfo._zidx:
+            if type(arg) in [StringType,UnicodeType] and arg.lower() in self._tzinfo._zidx:
                 # Current time, to be displayed in specified timezone
-                t,tz=time(),self._tzinfo._zmap[lower(arg)]
+                t,tz=time(),self._tzinfo._zmap[arg.lower()]
                 ms=(t-math.floor(t))
                 # Use integer arithmetic as much as possible.
                 s,d = _calcSD(t)
@@ -726,7 +650,7 @@ class DateTime:
                 x = _calcDependentSecond2(yr,mo,dy,hr,mn,sc)
 
                 if tz:
-                    try: tz=self._tzinfo._zmap[lower(tz)]
+                    try: tz=self._tzinfo._zmap[tz.lower()]
                     except KeyError:
                         if numericTimeZoneMatch(tz) is None:
                             raise self.DateTimeError, \
@@ -750,7 +674,7 @@ class DateTime:
                 # Seconds from epoch (gmt) and timezone
                 t,tz=args
                 ms = (t - math.floor(t))
-                tz=self._tzinfo._zmap[lower(tz)]
+                tz=self._tzinfo._zmap[tz.lower()]
                 # Use integer arithmetic as much as possible.
                 s,d = _calcSD(t)
                 x = _calcDependentSecond(tz, t)
@@ -794,7 +718,7 @@ class DateTime:
             x = _calcDependentSecond2(yr,mo,dy,hr,mn,sc)
             ms = sc - math.floor(sc)
             if tz:
-                try: tz=self._tzinfo._zmap[lower(tz)]
+                try: tz=self._tzinfo._zmap[tz.lower()]
                 except KeyError:
                     if numericTimeZoneMatch(tz) is None:
                         raise self.DateTimeError, \
@@ -910,7 +834,7 @@ class DateTime:
         tz = self.localZone(ltm)
         return tz
 
-    def _parse(self,string):
+    def _parse(self,st):
         # Parse date-time components from a string
         month=year=tz=tm=None
         spaces        =self.space_chars
@@ -925,22 +849,22 @@ class DateTime:
 
         # Find timezone first, since it should always be the last
         # element, and may contain a slash, confusing the parser.
-        string = strip(string)
-        sp=split(string)
+        st= st.strip()
+        sp=st.split()
         tz=sp[-1]
-        if tz and (lower(tz) in ValidZones): string=join(sp[:-1])
+        if tz and (tz.lower() in ValidZones): st=' '.join(sp[:-1])
         else: tz = None  # Decide later, since the default time zone
         # could depend on the date.
 
         ints,dels=[],[]
-        i,l=0,len(string)
+        i,l=0,len(st)
         while i < l:
-            while i < l and string[i] in spaces    : i=i+1
-            if i < l and string[i] in delimiters:
-                d=string[i]
+            while i < l and st[i] in spaces    : i=i+1
+            if i < l and st[i] in delimiters:
+                d=st[i]
                 i=i+1
             else: d=''
-            while i < l and string[i] in spaces    : i=i+1
+            while i < l and st[i] in spaces    : i=i+1
 
             # The float pattern needs to look back 1 character, because it
             # actually looks for a preceding colon like ':33.33'. This is
@@ -949,15 +873,15 @@ class DateTime:
             if i > 0: b=i-1
             else: b=i
 
-            ts_results = fltpat.match(string, b)
+            ts_results = fltpat.match(st, b)
             if ts_results:
                 s=ts_results.group(1)
                 i=i+len(s)
-                ints.append(atof(s))
+                ints.append(float(s))
                 continue
             
             #AJ
-            ts_results = intpat.match(string, i)
+            ts_results = intpat.match(st, i)
             if ts_results: 
                 s=ts_results.group(0)
 
@@ -967,31 +891,32 @@ class DateTime:
                     (len(ints) + (not not month) >= 3)):
                     tz='%s%s' % (d,s)
                 else:
-                    v=atoi(s)
+                    v=int(s)
                     ints.append(v)
                 continue
 
 
-            ts_results = wordpat.match(string, i)
+            ts_results = wordpat.match(st, i)
             if ts_results:
-                o,s=ts_results.group(0),lower(ts_results.group(0))
+                o,s=ts_results.group(0),ts_results.group(0).lower()
                 i=i+len(s)
-                if i < l and string[i]=='.': i=i+1
+                if i < l and st[i]=='.': i=i+1
                 # Check for month name:
                 if MonthNumbers.has_key(s):
                     v=MonthNumbers[s]
                     if month is None: month=v
-                    else: raise self.SyntaxError, string
+                    else: raise self.SyntaxError, st
                     continue
                 # Check for time modifier:
                 if s in TimeModifiers:
                     if tm is None: tm=s
-                    else: raise self.SyntaxError, string
+                    else: raise self.SyntaxError, st
                     continue
                 # Check for and skip day of week:
                 if DayOfWeekNames.has_key(s):
                     continue
-            raise self.SyntaxError, string
+                    
+            raise self.SyntaxError, st
 
         day=None
         if ints[-1] > 60 and d not in ['.',':'] and len(ints) > 2:
@@ -1049,34 +974,34 @@ class DateTime:
             year,month,day = localtime(time())[:3]
 
         year = _correctYear(year)
-        if year < 1000: raise self.SyntaxError, string
+        if year < 1000: raise self.SyntaxError, st
         
         leap = year%4==0 and (year%100!=0 or year%400==0)
         try:
             if not day or day > self._month_len[leap][month]:
-                raise self.DateError, string
+                raise self.DateError, st
         except IndexError:
-            raise self.DateError, string
+            raise self.DateError, st
         tod=0
         if ints:
             i=ints[0]
             # Modify hour to reflect am/pm
             if tm and (tm=='pm') and i<12:  i=i+12
             if tm and (tm=='am') and i==12: i=0
-            if i > 24: raise self.DateTimeError, string
+            if i > 24: raise self.DateTimeError, st
             tod = tod + int(i) * 3600
             del ints[0]
             if ints:
                 i=ints[0]
-                if i > 60: raise self.DateTimeError, string
+                if i > 60: raise self.DateTimeError, st
                 tod = tod + int(i) * 60
                 del ints[0]
                 if ints:
                     i=ints[0]
-                    if i > 60: raise self.DateTimeError, string
+                    if i > 60: raise self.DateTimeError, st
                     tod = tod + i
                     del ints[0]
-                    if ints: raise self.SyntaxError,string
+                    if ints: raise self.SyntaxError,st
 
         
         tod_int = int(math.floor(tod))
@@ -1118,7 +1043,7 @@ class DateTime:
     def toZone(self, z):
         """Return a DateTime with the value as the current
            object, represented in the indicated timezone."""
-        t,tz=self._t,self._tzinfo._zmap[lower(z)]
+        t,tz=self._t,self._tzinfo._zmap[z.lower()]
         millis = self.millis()
         #if (t>0 and ((t/86400.0) < 24837)):
         try:
@@ -1205,6 +1130,7 @@ class DateTime:
            the current object\'s day, in the object\'s timezone context"""
         return self.__class__(self._year,self._month,self._day,
                               23,59,59,self._tz)
+
     def greaterThan(self,t):
         """Compare this DateTime object to another DateTime object
            OR a floating point number such as that which is returned 
@@ -1214,8 +1140,15 @@ class DateTime:
            Revised to give more correct results through comparison of
            long integer milliseconds.
            """
-        try:    return (self.millis() > t.millis())
-        except: return (self._t > t)
+        # Optimized for sorting speed
+        try:
+            return (self._millis > t._millis)
+        except AttributeError:
+            try: self._millis
+            except AttributeError: self._upgrade_old()
+        return (self._t > t)
+
+    __gt__ = greaterThan
 
     def greaterThanEqualTo(self,t):
         """Compare this DateTime object to another DateTime object
@@ -1226,8 +1159,15 @@ class DateTime:
            Revised to give more correct results through comparison of
            long integer milliseconds.
            """           
-        try:    return (self.millis() >= t.millis())
-        except: return (self._t >= t)
+        # Optimized for sorting speed
+        try:
+            return (self._millis >= t._millis)
+        except AttributeError:
+            try: self._millis
+            except AttributeError: self._upgrade_old()
+        return (self._t >= t)
+
+    __ge__ = greaterThanEqualTo
 
     def equalTo(self,t):
         """Compare this DateTime object to another DateTime object
@@ -1238,8 +1178,15 @@ class DateTime:
            Revised to give more correct results through comparison of
            long integer milliseconds.
            """
-        try:    return (self.millis() == t.millis())
-        except: return (self._t == t)
+        # Optimized for sorting speed
+        try:
+            return (self._millis == t._millis)
+        except AttributeError:
+            try: self._millis
+            except AttributeError: self._upgrade_old()
+        return (self._t == t)
+
+    __eq__ = equalTo
 
     def notEqualTo(self,t):
         """Compare this DateTime object to another DateTime object
@@ -1250,8 +1197,15 @@ class DateTime:
            Revised to give more correct results through comparison of
            long integer milliseconds.
            """
-        try:    return (self.millis() != t.millis())
-        except: return (self._t != t)
+        # Optimized for sorting speed
+        try:
+            return (self._millis != t._millis)
+        except AttributeError:
+            try: self._millis
+            except AttributeError: self._upgrade_old()
+        return (self._t != t)
+
+    __ne__ = notEqualTo
 
     def lessThan(self,t):
         """Compare this DateTime object to another DateTime object
@@ -1262,8 +1216,15 @@ class DateTime:
            Revised to give more correct results through comparison of
            long integer milliseconds.
            """
-        try:    return (self.millis() < t.millis())
-        except: return (self._t < t)
+        # Optimized for sorting speed
+        try:
+            return (self._millis < t._millis)
+        except AttributeError:
+            try: self._millis
+            except AttributeError: self._upgrade_old()
+        return (self._t < t)
+
+    __lt__ = lessThan
 
     def lessThanEqualTo(self,t):
         """Compare this DateTime object to another DateTime object
@@ -1274,8 +1235,15 @@ class DateTime:
            Revised to give more correct results through comparison of
            long integer milliseconds.
            """
-        try:    return (self.millis() <= t.millis())
-        except: return (self._t <= t)
+        # Optimized for sorting speed
+        try:
+            return (self._millis <= t._millis)
+        except AttributeError:
+            try: self._millis
+            except AttributeError: self._upgrade_old()
+        return (self._t <= t)
+
+    __le__ = lessThanEqualTo
 
     def isLeapYear(self):
         """Return true if the current year (in the context of the object\'s
@@ -1386,11 +1354,15 @@ class DateTime:
 
     def millis(self):
         """Return the millisecond since the epoch in GMT."""
-        try: millis = self._millis
-        except:
-            # Upgrade a previously pickled DateTime object.
-            millis = long(math.floor(self._t * 1000.0))
-            self._millis = millis
+        try:
+            return self._millis
+        except AttributeError:
+            return self._upgrade_old()
+
+    def _upgrade_old(self):
+        """Upgrades a previously pickled DateTime object."""
+        millis = long(math.floor(self._t * 1000.0))
+        self._millis = millis
         return millis
 
     def strftime(self, format):
@@ -1562,7 +1534,7 @@ class DateTime:
                 try:
                     # For the seconds, print two digits
                     # before the decimal point.
-                    subsec = split('%g' % s, '.')[1]
+                    subsec = ('%g' % s).split('.')[1]
                     return '%4.4d/%2.2d/%2.2d %2.2d:%2.2d:%2.2d.%s %s' % (
                         y,m,d,h,mn,s,subsec,t)
                 except:
@@ -1586,8 +1558,13 @@ class DateTime:
            You should use the methods lessThan, greaterThan,
            lessThanEqualTo, greaterThanEqualTo, equalTo and
            notEqualTo to avoid potential problems later!!"""
-        try:                   return cmp(self.millis(), obj.millis())
-        except AttributeError: return cmp(self._t,obj)
+        # Optimized for sorting speed.
+        try:
+            return cmp(self._millis, obj._millis)
+        except AttributeError:
+            try: self._millis
+            except AttributeError: self._upgrade_old()
+        return cmp(self._t,obj)
 
     def __hash__(self):
         """Compute a hash value for a DateTime"""
@@ -1623,7 +1600,7 @@ class DateTime:
         try:
             return self.__parse_iso8601(s)
         except IndexError:
-            raise self.DateError,'Not an ISO 8601 compliant date string: "%s"' %  string
+            raise self.DateError,'Not an ISO 8601 compliant date string: "%s"' %  s
 
 
     def __parse_iso8601(self,s):
@@ -1639,25 +1616,25 @@ class DateTime:
     
         fields = datereg.split(s.strip())
         
-        if fields[1]:   year  = atoi(fields[1])
-        if fields[3]:   month = atoi(fields[3])
-        if fields[5]:   day   = atoi(fields[5])
+        if fields[1]:   year  = int(fields[1])
+        if fields[3]:   month = int(fields[3])
+        if fields[5]:   day   = int(fields[5])
     
         if s.find('T')>-1:
             fields = timereg.split(s[s.find('T')+1:])
     
-            if fields[1]:   hour     = atoi(fields[1])
-            if fields[3]:   minute   = atoi(fields[3])
-            if fields[5]:   seconds  = atoi(fields[5])
-            if fields[6]:   seconds  = seconds+atof(fields[6])
+            if fields[1]:   hour     = int(fields[1])
+            if fields[3]:   minute   = int(fields[3])
+            if fields[5]:   seconds  = int(fields[5])
+            if fields[6]:   seconds  = seconds+float(fields[6])
     
         if s.find('Z')>-1:
             pass
     
         if s[-3]==':' and s[-6] in ['+','-']:
-            hour_off = atoi(s[-6:-3])
-            min_off  = atoi(s[-2:])
-    
+            hour_off = int(s[-6:-3])
+            min_off  = int(s[-2:])
+
         return year,month,day,hour,minute,seconds,'GMT%+03d%02d' % (hour_off,min_off)
 
 
