@@ -1,85 +1,13 @@
 ##############################################################################
+#
+# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
 # 
-# Zope Public License (ZPL) Version 1.0
-# -------------------------------------
-# 
-# Copyright (c) Digital Creations.  All rights reserved.
-# 
-# This license has been certified as Open Source(tm).
-# 
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions are
-# met:
-# 
-# 1. Redistributions in source code must retain the above copyright
-#    notice, this list of conditions, and the following disclaimer.
-# 
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions, and the following disclaimer in
-#    the documentation and/or other materials provided with the
-#    distribution.
-# 
-# 3. Digital Creations requests that attribution be given to Zope
-#    in any manner possible. Zope includes a "Powered by Zope"
-#    button that is installed by default. While it is not a license
-#    violation to remove this button, it is requested that the
-#    attribution remain. A significant investment has been put
-#    into Zope, and this effort will continue if the Zope community
-#    continues to grow. This is one way to assure that growth.
-# 
-# 4. All advertising materials and documentation mentioning
-#    features derived from or use of this software must display
-#    the following acknowledgement:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    In the event that the product being advertised includes an
-#    intact Zope distribution (with copyright and license included)
-#    then this clause is waived.
-# 
-# 5. Names associated with Zope or Digital Creations must not be used to
-#    endorse or promote products derived from this software without
-#    prior written permission from Digital Creations.
-# 
-# 6. Modified redistributions of any form whatsoever must retain
-#    the following acknowledgment:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    Intact (re-)distributions of any official Zope release do not
-#    require an external acknowledgement.
-# 
-# 7. Modifications are encouraged but must be packaged separately as
-#    patches to official Zope releases.  Distributions that do not
-#    clearly separate the patches from the original work must be clearly
-#    labeled as unofficial distributions.  Modifications which do not
-#    carry the name Zope may be packaged in any form, as long as they
-#    conform to all of the clauses above.
-# 
-# 
-# Disclaimer
-# 
-#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
-#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
-#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
-#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-#   SUCH DAMAGE.
-# 
-# 
-# This software consists of contributions made by Digital Creations and
-# many individuals on behalf of Digital Creations.  Specific
-# attributions are listed in the accompanying credits file.
+# This software is subject to the provisions of the Zope Public License,
+# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
+# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
+# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
+# FOR A PARTICULAR PURPOSE
 # 
 ##############################################################################
 __doc__='''Variable insertion parameters
@@ -217,12 +145,11 @@ Evaluating expressions without rendering results
    
 
 ''' # '
-__rcs_id__='$Id: DT_Var.py,v 1.41.2.4 2001/11/09 19:12:44 andreasjung Exp $'
-__version__='$Revision: 1.41.2.4 $'[11:-2]
+__rcs_id__='$Id: DT_Var.py,v 1.49 2001/11/28 15:50:55 matt Exp $'
+__version__='$Revision: 1.49 $'[11:-2]
 
 from DT_Util import parse_params, name_param, str
 import re, string, sys
-from string import find, split, join, atoi, rfind
 from urllib import quote, quote_plus
 from cgi import escape
 from html_quote import html_quote # for import by other modules, dont remove!
@@ -257,7 +184,11 @@ class Var:
         if len(args)==1 and fmt=='s':
             if expr is None: expr=name
             else: expr=expr.eval
-            self.simple_form=expr,
+            self.simple_form=('v', expr)
+        elif len(args)==2  and fmt=='s' and args.has_key('html_quote'):
+            if expr is None: expr=name
+            else: expr=expr.eval
+            self.simple_form=('v', expr, 'h')
 
     def render(self, md):
         args=self.args
@@ -336,7 +267,7 @@ class Var:
                 tag with a non-integer value.''')
             if len(val) > size:
                 val=val[:size]
-                l=rfind(val,' ')
+                l=val.rfind(' ')
                 if l > size/2:
                     val=val[:l+1]
                 if have_arg('etc'): l=args['etc']
@@ -356,7 +287,7 @@ class Call:
         name, expr = name_param(args,'call',1)
         if expr is None: expr=name
         else: expr=expr.eval
-        self.simple_form=expr,None
+        self.simple_form=('i', expr, None)
 
 
 def url_quote(v, name='(Unknown name)', md={}):
@@ -368,8 +299,8 @@ def url_quote_plus(v, name='(Unknown name)', md={}):
 
 def newline_to_br(v, name='(Unknown name)', md={}):
     v=str(v)
-    if find(v,'\r') >= 0: v=join(split(v,'\r'),'')
-    if find(v,'\n') >= 0: v=join(split(v,'\n'),'<br>\n')
+    if v.find('\r') >= 0: v=''.join(v.split('\r'))
+    if v.find('\n') >= 0: v='<br>\n'.join(v.split('\n'))
     return v
 
 def whole_dollars(v, name='(Unknown name)', md={}):
@@ -384,11 +315,11 @@ def thousands_commas(v, name='(Unknown name)', md={},
                      thou=re.compile(
                          r"([0-9])([0-9][0-9][0-9]([,.]|$))").search):
     v=str(v)
-    vl=split(v,'.')
+    vl=v.split('.')
     if not vl: return v
     v=vl[0]
     del vl[0]
-    if vl: s='.'+join(vl,'.')
+    if vl: s='.'+'.'.join(vl)
     else: s=''
     mo=thou(v)
     while mo is not None:
@@ -413,7 +344,6 @@ def len_format(v, name='(Unknown name)', md={}):
 def len_comma(v, name='(Unknown name)', md={}):
     return thousands_commas(str(len(v)))
 
-
 StructuredText=None
 def structured_text(v, name='(Unknown name)', md={}):
     global StructuredText
@@ -429,13 +359,14 @@ def structured_text(v, name='(Unknown name)', md={}):
         
     return HTML(txt,level=3,header=0)
         
+
 def sql_quote(v, name='(Unknown name)', md={}):
     """Quote single quotes in a string by doubling them.
 
     This is needed to securely insert values into sql
     string literals in templates that generate sql.
     """
-    if find(v,"'") >= 0: return join(split(v,"'"),"''")
+    if v.find("'") >= 0: return "''".join(v.split("'"))
     return v
 
 special_formats={
@@ -456,7 +387,7 @@ special_formats={
     }
 
 def spacify(val):
-    if find(val,'_') >= 0: val=join(split(val,'_'))
+    if val.find('_') >= 0: val=" ".join(val.split('_'))
     return val
 
 modifiers=(html_quote, url_quote, url_quote_plus, newline_to_br,
