@@ -1,103 +1,29 @@
 ##############################################################################
+#
+# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
 # 
-# Zope Public License (ZPL) Version 1.0
-# -------------------------------------
-# 
-# Copyright (c) Digital Creations.  All rights reserved.
-# 
-# This license has been certified as Open Source(tm).
-# 
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions are
-# met:
-# 
-# 1. Redistributions in source code must retain the above copyright
-#    notice, this list of conditions, and the following disclaimer.
-# 
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions, and the following disclaimer in
-#    the documentation and/or other materials provided with the
-#    distribution.
-# 
-# 3. Digital Creations requests that attribution be given to Zope
-#    in any manner possible. Zope includes a "Powered by Zope"
-#    button that is installed by default. While it is not a license
-#    violation to remove this button, it is requested that the
-#    attribution remain. A significant investment has been put
-#    into Zope, and this effort will continue if the Zope community
-#    continues to grow. This is one way to assure that growth.
-# 
-# 4. All advertising materials and documentation mentioning
-#    features derived from or use of this software must display
-#    the following acknowledgement:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    In the event that the product being advertised includes an
-#    intact Zope distribution (with copyright and license included)
-#    then this clause is waived.
-# 
-# 5. Names associated with Zope or Digital Creations must not be used to
-#    endorse or promote products derived from this software without
-#    prior written permission from Digital Creations.
-# 
-# 6. Modified redistributions of any form whatsoever must retain
-#    the following acknowledgment:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    Intact (re-)distributions of any official Zope release do not
-#    require an external acknowledgement.
-# 
-# 7. Modifications are encouraged but must be packaged separately as
-#    patches to official Zope releases.  Distributions that do not
-#    clearly separate the patches from the original work must be clearly
-#    labeled as unofficial distributions.  Modifications which do not
-#    carry the name Zope may be packaged in any form, as long as they
-#    conform to all of the clauses above.
-# 
-# 
-# Disclaimer
-# 
-#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
-#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
-#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
-#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-#   SUCH DAMAGE.
-# 
-# 
-# This software consists of contributions made by Digital Creations and
-# many individuals on behalf of Digital Creations.  Specific
-# attributions are listed in the accompanying credits file.
+# This software is subject to the provisions of the Zope Public License,
+# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
+# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
+# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
+# FOR A PARTICULAR PURPOSE
 # 
 ##############################################################################
 """Document Template Tests
 """
 
-__rcs_id__='$Id: testDTML.py,v 1.5.4.1 2001/07/02 16:29:11 shane Exp $'
-__version__='$Revision: 1.5.4.1 $'[11:-2]
+__rcs_id__='$Id: testDTML.py,v 1.9 2001/11/28 15:50:56 matt Exp $'
+__version__='$Revision: 1.9 $'[11:-2]
 
 import sys, os
 import unittest
 
 if __name__=='__main__':
-    sys.path.append(os.path.join(os.pardir, os.pardir))
     here = os.curdir
 else:
     from DocumentTemplate import tests
-    from App.Common import package_home
-    here = package_home(tests.__dict__)
+    here = tests.__path__[0]
 
 def read_file(name):
     f = open(os.path.join(here, name), 'rb')
@@ -105,7 +31,7 @@ def read_file(name):
     f.close()
     return res
 
-from DocumentTemplate import HTML, String
+from DocumentTemplate.DT_HTML import HTML, String
 from ExtensionClass import Base
 class D:
     __allow_access_to_unprotected_subobjects__ = 1
@@ -122,7 +48,7 @@ class DTMLTests (unittest.TestCase):
 
     doc_class = HTML
 
-    def checkBatchingEtc(self):
+    def testBatchingEtc(self):
 
         def item(key,**kw): return (key,kw)
         def item2(key,**kw): return kw
@@ -239,7 +165,7 @@ class DTMLTests (unittest.TestCase):
         expected = read_file('dealers.out')
         assert res == expected, res
 
-    def checkSequenceSummaries(self):
+    def testSequenceSummaries(self):
         def d(**kw): return kw
         data=(d(name='jim', age=38),
               # d(name='kak', age=40),
@@ -274,7 +200,7 @@ class DTMLTests (unittest.TestCase):
                     'median=5 mean=12.5 s.d.=17')
         assert res == expected, res
 
-    def checkDTMLDateFormatting(self):
+    def testDTMLDateFormatting(self):
         import DateTime
         html = self.doc_class(
         "<dtml-var name capitalize spacify> is "
@@ -285,13 +211,13 @@ class DTMLTests (unittest.TestCase):
         expected = 'Christmas day is 1995/12/25'
         assert res == expected, res
 
-    def checkSimpleString(self):
+    def testSimpleString(self):
         dt = String('%(name)s')
         res = dt(name='Chris')
         expected = 'Chris'
         assert res == expected, res
 
-    def checkStringDateFormatting(self):
+    def testStringDateFormatting(self):
         import DateTime
         html = String("%(name capitalize spacify)s is "
                       "%(date fmt=year)s/%(date fmt=month)s/%(date fmt=day)s")
@@ -300,7 +226,7 @@ class DTMLTests (unittest.TestCase):
         expected = 'The date is 2001/4/27'
         assert res == expected, res
 
-    def checkSequence1(self):
+    def testSequence1(self):
         html=self.doc_class(
             '<dtml-in spam><dtml-in sequence-item><dtml-var sequence-item> '
             '</dtml-in sequence-item></dtml-in spam>')
@@ -308,7 +234,7 @@ class DTMLTests (unittest.TestCase):
         res = html(spam=[[1,2,3],[4,5,6]])
         assert res == expected, res
 
-    def checkSequence2(self):
+    def testSequence2(self):
         html=self.doc_class(
             '<dtml-in spam><dtml-in sequence-item><dtml-var sequence-item>-'
             '</dtml-in sequence-item></dtml-in spam>')
@@ -316,14 +242,14 @@ class DTMLTests (unittest.TestCase):
         res = html(spam=[[1,2,3],[4,5,6]])
         assert res == expected, res
 
-    def checkNull(self):
+    def testNull(self):
         html=self.doc_class('<dtml-var spam fmt="$%.2f bobs your uncle" '
                   'null="spam%eggs!|">')
         expected = '$42.00 bobs your unclespam%eggs!|'
         res = html(spam=42) + html(spam=None)
         assert res == expected, res
 
-    def check_fmt(self):
+    def test_fmt(self):
         html=self.doc_class(
             """
             <dtml-var spam>
@@ -369,7 +295,7 @@ foo bar
             spam='<a href="spam">\nfoo bar')
         assert res == expected, res
 
-    def checkPropogatedError(self):
+    def testPropogatedError(self):
 
         class foo:
             def __len__(self): return 9
@@ -408,7 +334,7 @@ foo bar
         else:
             assert 0, 'Puke error not propogated'
 
-    def checkRenderCallable(self):
+    def testRenderCallable(self):
         "Test automatic rendering of callable objects"
         class C (Base):
             __allow_access_to_unprotected_subobjects__ = 1
@@ -433,7 +359,7 @@ foo bar
             <dtml-var expr="_.render(i.h2)">''')(i=C())
         assert res == expected, res
 
-    def checkWith(self):
+    def testWith(self):
         class person:
             __allow_access_to_unprotected_subobjects__ = 1
             name='Jim'
@@ -448,7 +374,7 @@ foo bar
             'cm.</dtml-with>')(person=person)
         assert res == expected, res
 
-    def checkRaise(self):
+    def testRaise(self):
         try:
             res = self.doc_class(
             "<dtml-raise IndexError>success!</dtml-raise>")()
@@ -457,7 +383,7 @@ foo bar
         assert str(res) == 'success!', `res`
 
 
-    def checkBasicHTMLIn(self):
+    def testBasicHTMLIn(self):
         data=(
             d(name='jim', age=39),
             d(name='kak', age=29),
@@ -481,7 +407,7 @@ foo bar
         result = self.doc_class(html)(data=data)
         assert result == expected, result
 
-    def checkBasicHTMLIn2(self):
+    def testBasicHTMLIn2(self):
         xxx=(D(name=1), D(name=2), D(name=3))
         html = """
 <!--#in xxx-->
@@ -496,7 +422,7 @@ foo bar
         result = self.doc_class(html)(xxx=xxx)
         assert result == expected, result
 
-    def checkBasicHTMLIn3(self):
+    def testBasicHTMLIn3(self):
         ns = {'prop_ids': ('title', 'id'), 'title': 'good', 'id': 'times'}
         html = """:<dtml-in prop_ids><dtml-var sequence-item>=<dtml-var
         expr="_[_['sequence-item']]">:</dtml-in>"""
@@ -505,7 +431,7 @@ foo bar
 
         assert result == expected, result
 
-    def checkHTMLInElse(self):
+    def testHTMLInElse(self):
         xxx=(D(name=1), D(name=2), D(name=3))
         html="""
 <!--#in data mapping-->
@@ -524,7 +450,7 @@ foo bar
         result = self.doc_class(html)(xxx=xxx, data={})
         assert result == expected, result
         
-    def checkBasicStringIn(self):
+    def testBasicStringIn(self):
         data=(
             d(name='jim', age=39),
             d(name='kak', age=29),
@@ -548,22 +474,12 @@ foo bar
         assert expected == result, result
         
 def test_suite():
-    return unittest.makeSuite(DTMLTests, 'check')
+    suite = unittest.TestSuite()
+    suite.addTest( unittest.makeSuite( DTMLTests ) )
+    return suite
 
 def main():
-    alltests = test_suite()
-    runner = unittest.TextTestRunner()
-    runner.run(alltests)
+    unittest.TextTestRunner().run(test_suite())
 
-def debug():
-   test_suite().debug()
-
-def pdebug():
-    import pdb
-    pdb.run('debug()')
-
-if __name__=='__main__':
-    if len(sys.argv) > 1:
-        globals()[sys.argv[1]]()
-    else:
-        main()
+if __name__ == '__main__':
+    main()
