@@ -1,98 +1,27 @@
 ##############################################################################
+#
+# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
 # 
-# Zope Public License (ZPL) Version 1.0
-# -------------------------------------
-# 
-# Copyright (c) Digital Creations.  All rights reserved.
-# 
-# This license has been certified as Open Source(tm).
-# 
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions are
-# met:
-# 
-# 1. Redistributions in source code must retain the above copyright
-#    notice, this list of conditions, and the following disclaimer.
-# 
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions, and the following disclaimer in
-#    the documentation and/or other materials provided with the
-#    distribution.
-# 
-# 3. Digital Creations requests that attribution be given to Zope
-#    in any manner possible. Zope includes a "Powered by Zope"
-#    button that is installed by default. While it is not a license
-#    violation to remove this button, it is requested that the
-#    attribution remain. A significant investment has been put
-#    into Zope, and this effort will continue if the Zope community
-#    continues to grow. This is one way to assure that growth.
-# 
-# 4. All advertising materials and documentation mentioning
-#    features derived from or use of this software must display
-#    the following acknowledgement:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    In the event that the product being advertised includes an
-#    intact Zope distribution (with copyright and license included)
-#    then this clause is waived.
-# 
-# 5. Names associated with Zope or Digital Creations must not be used to
-#    endorse or promote products derived from this software without
-#    prior written permission from Digital Creations.
-# 
-# 6. Modified redistributions of any form whatsoever must retain
-#    the following acknowledgment:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    Intact (re-)distributions of any official Zope release do not
-#    require an external acknowledgement.
-# 
-# 7. Modifications are encouraged but must be packaged separately as
-#    patches to official Zope releases.  Distributions that do not
-#    clearly separate the patches from the original work must be clearly
-#    labeled as unofficial distributions.  Modifications which do not
-#    carry the name Zope may be packaged in any form, as long as they
-#    conform to all of the clauses above.
-# 
-# 
-# Disclaimer
-# 
-#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
-#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
-#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
-#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-#   SUCH DAMAGE.
-# 
-# 
-# This software consists of contributions made by Digital Creations and
-# many individuals on behalf of Digital Creations.  Specific
-# attributions are listed in the accompanying credits file.
+# This software is subject to the provisions of the Zope Public License,
+# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
+# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
+# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
+# FOR A PARTICULAR PURPOSE
 # 
 ##############################################################################
 __doc__="""Object Manager
 
-$Id: ObjectManager.py,v 1.137.4.7 2001/10/26 15:14:09 andreasjung Exp $"""
+$Id: ObjectManager.py,v 1.145 2001/11/28 15:50:57 matt Exp $"""
 
-__version__='$Revision: 1.137.4.7 $'[11:-2]
+__version__='$Revision: 1.145 $'[11:-2]
 
 import App.Management, Acquisition, Globals, CopySupport, Products
 import os, App.FactoryDispatcher, re, Products
 from OFS.Traversable import Traversable
 from Globals import DTMLFile, Persistent
 from Globals import MessageDialog, default__class_init__
+from Globals import REPLACEABLE, NOT_REPLACEABLE, UNIQUE
 from webdav.NullResource import NullResource
 from webdav.Collection import Collection
 from Acquisition import aq_base
@@ -109,12 +38,7 @@ customImporters={
     XMLExportImport.magic: XMLExportImport.importXML,
     }
 
-bad_id=re.compile(r'[^a-zA-Z0-9-_~,.$#\(\) ]').search #TS
-
-# Global constants: __replaceable__ flags:
-NOT_REPLACEABLE = 0
-REPLACEABLE = 1
-UNIQUE = 2
+bad_id=re.compile(r'[^a-zA-Z0-9-_~,.$\(\)# ]').search #TS
 
 BadRequestException = 'Bad Request'
 
@@ -124,6 +48,7 @@ def checkValidId(self, id, allow_dup=0):
     # only check that the id string contains no illegal chars;
     # check_valid_id() will be called again later with allow_dup
     # set to false before the object is added.
+
     if not id or (type(id) != type('')):
         raise BadRequestException, 'Empty or invalid id specified.'
     if bad_id(id) is not None:
@@ -317,9 +242,10 @@ class ObjectManager(
             if hasattr(object, '__ac_local_roles__'):
                 if object.__ac_local_roles__ is None:
                     user=getSecurityManager().getUser()
-                    name=user.getUserName()
-                    if name != 'Anonymous User':
-                        object.manage_setLocalRoles(name, ['Owner'])
+                    if user is not None:
+                        name=user.getUserName()
+                        if name != 'Anonymous User':
+                            object.manage_setLocalRoles(name, ['Owner'])
 
         object.manage_afterAdd(object, self)
         return id
@@ -567,13 +493,23 @@ class ObjectManager(
         software_home = os.path.join(SOFTWARE_HOME, '..%s..' % os.sep)
         software_home = os.path.normpath(software_home)
         
-        
         for impath in (instance_home, software_home):
             filepath = os.path.join(impath, 'import', file)
             if os.path.exists(filepath):
                 break
         else:
             raise BadRequestException, 'File does not exist: %s' % file
+
+        self._importObjectFromFile(filepath, verify=not not REQUEST,
+                                   set_owner=set_owner)
+        
+        if REQUEST is not None:
+            return self.manage_main(self, REQUEST, 
+                manage_tabs_message='<em>%s</em> sucessfully imported' % id,
+                title = 'Object imported',
+                update_menu=1)
+
+    def _importObjectFromFile(self, filepath, verify=1, set_owner=1):
         # locate a valid connection
         connection=self._p_jar
         obj=self
@@ -583,9 +519,7 @@ class ObjectManager(
             connection=obj._p_jar
         ob=connection.importFile(
             filepath, customImporters=customImporters)
-        if REQUEST: self._verifyObjectPaste(ob, validate_src=0)
-        #id=ob.getId()
-        #can't use above getId() call, it fails on 'old' exported objects
+        if verify: self._verifyObjectPaste(ob, validate_src=0)
         id=ob.id
         if hasattr(id, 'im_func'): id=id()
         self._setObject(id, ob, set_owner=set_owner)
@@ -595,13 +529,6 @@ class ObjectManager(
         ob=self._getOb(id)
         ob.manage_changeOwnershipType(explicit=0)
 
-        if REQUEST is not None:
-            return self.manage_main(self, REQUEST, 
-                manage_tabs_message='<em>%s</em> sucessfully imported' % id,
-                title = 'Object imported',
-                update_menu=1)
-
-
     # FTP support methods
     
     def manage_FTPlist(self, REQUEST):
