@@ -1,85 +1,13 @@
 ##############################################################################
+#
+# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
 # 
-# Zope Public License (ZPL) Version 1.0
-# -------------------------------------
-# 
-# Copyright (c) Digital Creations.  All rights reserved.
-# 
-# This license has been certified as Open Source(tm).
-# 
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions are
-# met:
-# 
-# 1. Redistributions in source code must retain the above copyright
-#    notice, this list of conditions, and the following disclaimer.
-# 
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions, and the following disclaimer in
-#    the documentation and/or other materials provided with the
-#    distribution.
-# 
-# 3. Digital Creations requests that attribution be given to Zope
-#    in any manner possible. Zope includes a "Powered by Zope"
-#    button that is installed by default. While it is not a license
-#    violation to remove this button, it is requested that the
-#    attribution remain. A significant investment has been put
-#    into Zope, and this effort will continue if the Zope community
-#    continues to grow. This is one way to assure that growth.
-# 
-# 4. All advertising materials and documentation mentioning
-#    features derived from or use of this software must display
-#    the following acknowledgement:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    In the event that the product being advertised includes an
-#    intact Zope distribution (with copyright and license included)
-#    then this clause is waived.
-# 
-# 5. Names associated with Zope or Digital Creations must not be used to
-#    endorse or promote products derived from this software without
-#    prior written permission from Digital Creations.
-# 
-# 6. Modified redistributions of any form whatsoever must retain
-#    the following acknowledgment:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    Intact (re-)distributions of any official Zope release do not
-#    require an external acknowledgement.
-# 
-# 7. Modifications are encouraged but must be packaged separately as
-#    patches to official Zope releases.  Distributions that do not
-#    clearly separate the patches from the original work must be clearly
-#    labeled as unofficial distributions.  Modifications which do not
-#    carry the name Zope may be packaged in any form, as long as they
-#    conform to all of the clauses above.
-# 
-# 
-# Disclaimer
-# 
-#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
-#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
-#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
-#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-#   SUCH DAMAGE.
-# 
-# 
-# This software consists of contributions made by Digital Creations and
-# many individuals on behalf of Digital Creations.  Specific
-# attributions are listed in the accompanying credits file.
+# This software is subject to the provisions of the Zope Public License,
+# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
+# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
+# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
+# FOR A PARTICULAR PURPOSE
 # 
 ##############################################################################
 
@@ -87,10 +15,10 @@
 
 """
 
-__version__ = '$Revision: 1.9.2.6 $'[11:-2]
+__version__ = '$Revision: 1.25 $'[11:-2]
 
 
-import string, re
+import  re
 import operator,warnings
 from Globals import Persistent,DTMLFile
 from zLOG import LOG, ERROR
@@ -189,14 +117,12 @@ class TextIndex(PluggableIndex.PluggableIndex, Persistent,
         # Default text index operator (should be visible to ZMI)
         self.useOperator  = 'or'
 
-        self.clear()
 
         if extra:   self.vocabulary_id = extra.vocabulary
         else:       self.vocabulary_id = "Vocabulary"
 
-        
-
         self._lexicon = None
+        self.clear()
 
         if lexicon is not None:
 
@@ -210,11 +136,13 @@ class TextIndex(PluggableIndex.PluggableIndex, Persistent,
     def getLexicon(self, vocab_id=None):
         """Return the Lexicon in use. Removed lots of stinking code"""
 
-        
-
         if self._lexicon is None:
             ## if no lexicon is provided, create a default one
             try:
+
+                if self.catalog is None:
+                    self.catalog = self.aq_inner.aq_parent.aq_base
+                
                 self._lexicon = getattr(self.catalog,self.vocabulary_id).getLexicon()
             except:                
                 self._lexicon = Lexicon()
@@ -232,6 +160,8 @@ class TextIndex(PluggableIndex.PluggableIndex, Persistent,
         """Reinitialize the text index."""
         self._index   = IOBTree()
         self._unindex = IOBTree()
+        if self.getLexicon():
+            self.getLexicon().clear()
         self._lexicon = None
 
     def _convertBTrees(self, threshold=200):
@@ -357,6 +287,18 @@ class TextIndex(PluggableIndex.PluggableIndex, Persistent,
                 source = str(source)
         except (AttributeError, TypeError):
             return 0
+
+        # sniff the object for 'id'+'_encoding'
+        
+        try:
+            encoding = getattr(obj, self.id+'_encoding')
+            if callable(encoding ):
+                encoding = str(encoding())
+            else:
+                encoding = str(encoding)
+        except (AttributeError, TypeError):
+            encoding = 'latin1'
+
         
         lexicon = self.getLexicon()
 
@@ -366,7 +308,8 @@ class TextIndex(PluggableIndex.PluggableIndex, Persistent,
         last = None
         
         # Run through the words and score them
-        for word in splitter(source):
+
+        for word in list(splitter(source,encoding=encoding)):
             if word[0] == '\"':
                 last = self._subindex(word[1:-1], wordScores, last, splitter)
             else:
@@ -466,6 +409,7 @@ class TextIndex(PluggableIndex.PluggableIndex, Persistent,
             result = self._index.get(word, {})
             return ResultList(result, (word,), self)
         else:
+
             splitSource = tuple(self.getLexicon().Splitter(word))
 
             if not splitSource:
@@ -540,7 +484,7 @@ class TextIndex(PluggableIndex.PluggableIndex, Persistent,
         r = None
 
         for key in record.keys:
-            key = string.strip(key)
+            key = key.strip()
             if not key:
                 continue
 
@@ -621,7 +565,6 @@ class TextIndex(PluggableIndex.PluggableIndex, Persistent,
 
     def get_operands(self, q, i):
         """Evaluate and return the left and right operands for an operator"""
-
         try:
             left  = q[i - 1]
             right = q[i + 1]
@@ -631,7 +574,7 @@ class TextIndex(PluggableIndex.PluggableIndex, Persistent,
         operandType = type(left)
         if operandType is IntType:
             left = self[left]
-        elif operandType is StringType:
+        elif isinstance(left,StringType) or isinstance(left,UnicodeType):
             left = self[left]        
         elif operandType is ListType:
             left = self.evaluate(left)
@@ -639,7 +582,7 @@ class TextIndex(PluggableIndex.PluggableIndex, Persistent,
         operandType = type(right)
         if operandType is IntType:
             right = self[right]
-        elif operandType is StringType:
+        elif isinstance(right,StringType) or isinstance(right,UnicodeType):
             right = self[right]       
         elif operandType is ListType:
             right = self.evaluate(right)
@@ -723,7 +666,7 @@ class TextIndex(PluggableIndex.PluggableIndex, Persistent,
 def parse(s):
     """Parse parentheses and quotes"""
     l = []
-    tmp = string.lower(s)
+    tmp = s.lower()
 
     p = parens(tmp)
     while p is not None:
@@ -788,9 +731,9 @@ def parens(s, parens_re=re.compile('[()]').search):
 
 
 def quotes(s):
-    split=string.split
+
     if '"' not in s:
-        return split(s)
+        return s.split()
     
     # split up quoted regions
     splitted = re.split('\s*\"\s*', s)
@@ -799,7 +742,7 @@ def quotes(s):
     
     for i in range(1,len(splitted),2):
         # split the quoted region into words
-        words = splitted[i] = split(splitted[i])
+        words = splitted[i] = splitted[i].split()
         
         # put the Proxmity operator in between quoted words
         j = len(words) - 1
@@ -810,7 +753,7 @@ def quotes(s):
     i = len(splitted) - 1
     while i >= 0:
         # split the non-quoted region into words
-        splitted[i:i+1] = split(splitted[i])
+        splitted[i:i+1] = splitted[i].split()
         i = i - 2
 
     return filter(None, splitted)
