@@ -1,85 +1,13 @@
 ##############################################################################
+#
+# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
 # 
-# Zope Public License (ZPL) Version 1.0
-# -------------------------------------
-# 
-# Copyright (c) Digital Creations.  All rights reserved.
-# 
-# This license has been certified as Open Source(tm).
-# 
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions are
-# met:
-# 
-# 1. Redistributions in source code must retain the above copyright
-#    notice, this list of conditions, and the following disclaimer.
-# 
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions, and the following disclaimer in
-#    the documentation and/or other materials provided with the
-#    distribution.
-# 
-# 3. Digital Creations requests that attribution be given to Zope
-#    in any manner possible. Zope includes a "Powered by Zope"
-#    button that is installed by default. While it is not a license
-#    violation to remove this button, it is requested that the
-#    attribution remain. A significant investment has been put
-#    into Zope, and this effort will continue if the Zope community
-#    continues to grow. This is one way to assure that growth.
-# 
-# 4. All advertising materials and documentation mentioning
-#    features derived from or use of this software must display
-#    the following acknowledgement:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    In the event that the product being advertised includes an
-#    intact Zope distribution (with copyright and license included)
-#    then this clause is waived.
-# 
-# 5. Names associated with Zope or Digital Creations must not be used to
-#    endorse or promote products derived from this software without
-#    prior written permission from Digital Creations.
-# 
-# 6. Modified redistributions of any form whatsoever must retain
-#    the following acknowledgment:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    Intact (re-)distributions of any official Zope release do not
-#    require an external acknowledgement.
-# 
-# 7. Modifications are encouraged but must be packaged separately as
-#    patches to official Zope releases.  Distributions that do not
-#    clearly separate the patches from the original work must be clearly
-#    labeled as unofficial distributions.  Modifications which do not
-#    carry the name Zope may be packaged in any form, as long as they
-#    conform to all of the clauses above.
-# 
-# 
-# Disclaimer
-# 
-#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
-#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
-#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
-#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-#   SUCH DAMAGE.
-# 
-# 
-# This software consists of contributions made by Digital Creations and
-# many individuals on behalf of Digital Creations.  Specific
-# attributions are listed in the accompanying credits file.
+# This software is subject to the provisions of the Zope Public License,
+# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
+# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
+# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
+# FOR A PARTICULAR PURPOSE
 # 
 ##############################################################################
 # 
@@ -109,6 +37,8 @@
 #   -   user name
 #   
 #   -   description
+#
+#   -   extension attributes
 # 
 #   * A sequence of data records
 #   
@@ -184,7 +114,7 @@
 #   may have a back pointer to a version record or to a non-version
 #   record.
 #
-__version__='$Revision: 1.60.4.2 $'[11:-2]
+__version__='$Revision: 1.76 $'[11:-2]
 
 import struct, time, os, bpthread, string, base64, sys
 from struct import pack, unpack
@@ -251,77 +181,78 @@ class FileStorage(BaseStorage.BaseStorage,
     def __init__(self, file_name, create=0, read_only=0, stop=None,
                  quota=None):
 
-        if not os.path.exists(file_name): create = 1
+        if not os.path.exists(file_name):
+            create = 1
 
         if read_only:
-            if create: raise ValueError, "can\'t create a read-only file"
+            if create:
+                raise ValueError, "can\'t create a read-only file"
         elif stop is not None:
             raise ValueError, "time-travel is only supported in read-only mode"
 
-        if stop is None: stop='\377'*8
+        if stop is None:
+            stop='\377'*8
 
         # Lock the database and set up the temp file.
         if not read_only:
-            try: f=open(file_name+'.lock', 'r+')
-            except: f=open(file_name+'.lock', 'w+')
+            try:
+                f = open(file_name + '.lock', 'r+')
+            except:
+                f = open(file_name+'.lock', 'w+')
             lock_file(f)
             try:
                 f.write(str(os.getpid()))
                 f.flush()
-            except: pass
-            self._lock_file=f # so it stays open
-
-            self._tfile=open(file_name+'.tmp','w+b')
+            except:
+                pass
+            self._lock_file = f # so it stays open
 
+            self._tfile = open(file_name + '.tmp', 'w+b')
         else:
+            self._tfile = None
 
-            self._tfile=None
-
-        self._file_name=file_name
+        self._file_name = file_name
 
         BaseStorage.BaseStorage.__init__(self, file_name)
 
         index, vindex, tindex, tvindex = self._newIndexes()
-
         self._initIndex(index, vindex, tindex, tvindex)
         
         # Now open the file
         
         if create:
-            if os.path.exists(file_name): os.remove(file_name)
-            file=open(file_name,'w+b')
-            file.write(packed_version)
+            if os.path.exists(file_name):
+                os.remove(file_name)
+            self._file = open(file_name, 'w+b')
+            self._file.write(packed_version)
         else:
-            file=open(file_name, read_only and 'rb' or 'r+b')
+            self._file = open(file_name, read_only and 'rb' or 'r+b')
 
-        self._file=file
-
-        r=self._restore_index()
-        if r:
+        r = self._restore_index()
+        if r is not None:
             index, vindex, start, maxoid, ltid = r
             self._initIndex(index, vindex, tindex, tvindex)
             self._pos, self._oid, tid = read_index(
-                file, file_name, index, vindex, tindex, stop,
+                self._file, file_name, index, vindex, tindex, stop,
                 ltid=ltid, start=start, maxoid=maxoid,
                 read_only=read_only,
                 )
         else:
             self._pos, self._oid, tid = read_index(
-                file, file_name, index, vindex, tindex, stop,
+                self._file, file_name, index, vindex, tindex, stop,
                 read_only=read_only,
                 )
 
-        self._ts=tid=TimeStamp(tid)
-        t=time.time()
-        t=apply(TimeStamp,(time.gmtime(t)[:5]+(t%60,)))
+        self._ts = tid = TimeStamp(tid)
+        t = time.time()
+        t = apply(TimeStamp, (time.gmtime(t)[:5] + (t % 60,)))
         if tid > t:
             warn("%s Database records in the future", file_name);
             if tid.timeTime() - t.timeTime() > 86400*30:
                 # a month in the future? This is bogus, use current time
-                self._ts=t
+                self._ts = t
 
-        self._quota=quota
-            
+        self._quota = quota
 
     def _initIndex(self, index, vindex, tindex, tvindex):
         self._index=index
@@ -333,7 +264,9 @@ class FileStorage(BaseStorage.BaseStorage,
 
     def __len__(self): return len(self._index)
 
-    def _newIndexes(self): return {}, {}, {}, {}
+    def _newIndexes(self):
+        # hook to use something other than builtin dict
+        return {}, {}, {}, {}
         
     def abortVersion(self, src, transaction):
         return self.commitVersion(src, '', transaction, abort=1)
@@ -355,15 +288,20 @@ class FileStorage(BaseStorage.BaseStorage,
         f.flush()
         f.close()
         try:
-            try: os.unlink(index_name)
-            except: pass
+            try:
+                os.remove(index_name)
+            except OSError:
+                pass
             os.rename(tmp_name, index_name)
         except: pass
 
     def _clear_index(self):
         index_name=self.__name__+'.index'
         if os.path.exists(index_name):
-            os.unlink(index_name)
+            try:
+                os.remove(index_name)
+            except OSError:
+                pass
 
     def _sane(self, index, pos):
         """Sanity check saved index data by reading the last undone trans
@@ -372,8 +310,8 @@ class FileStorage(BaseStorage.BaseStorage,
         check to see that the included records are consistent
         with the index.  Any invalid record records or inconsistent
         object positions cause zero to be returned.
-
         """
+        
         if pos < 100: return 0
         file=self._file
         seek=file.seek
@@ -394,7 +332,7 @@ class FileStorage(BaseStorage.BaseStorage,
             if stl != rstl: return 0 # inconsistent lengths
             if status == 'u': continue # undone trans, search back
             if status not in ' p': return 0
-            if ul > tl or dl > tl or el > tl or tl < (23+ul+dl+el): return 0
+            if tl < (23+ul+dl+el): return 0
             tend=pos+tl
             opos=pos+(23+ul+dl+el)
             if opos==tend: continue # empty trans
@@ -412,7 +350,7 @@ class FileStorage(BaseStorage.BaseStorage,
     
                 if opos+dlen > tend or tloc != pos: return 0
 
-                if index.get(oid,0) != opos: return 0
+                if index.get(oid, 0) != opos: return 0
     
                 opos=opos+dlen
 
@@ -429,13 +367,20 @@ class FileStorage(BaseStorage.BaseStorage,
         
         p=Unpickler(f)
 
-        info=p.load()
-        index=info.get('index', None)
-        pos=long(info.get('pos', None))
-        oid=info.get('oid', None)
-        vindex=info.get('vindex', None)
+        try:
+            info=p.load()
+        except:
+            exc, err = sys.exc_info()[:2]
+            warn("Failed to load database index: %s: %s" %
+                 (exc, err))
+            return None
+        index=info.get('index')
+        pos=info.get('pos')
+        oid=info.get('oid')
+        vindex=info.get('vindex')
         if index is None or pos is None or oid is None or vindex is None:
             return None
+        pos = long(pos)
 
         tid=self._sane(index, pos)
         if not tid: return None
@@ -444,7 +389,6 @@ class FileStorage(BaseStorage.BaseStorage,
 
     def close(self):
         self._file.close()
-
         if hasattr(self,'_lock_file'):  self._lock_file.close()
         if self._tfile:                 self._tfile.close()
         try: self._save_index()
@@ -452,15 +396,17 @@ class FileStorage(BaseStorage.BaseStorage,
         
     def commitVersion(self, src, dest, transaction, abort=None):
         # We are going to commit by simply storing back pointers.
-
-        if (not src or
-            type(src) is not StringType or type(dest) is not StringType
-            ):
+        if not (src and isinstance(src, StringType)
+                and isinstance(dest, StringType)):
             raise POSException.VersionCommitError('Invalid source version')
 
+        if src == dest:
+            raise POSException.VersionCommitError(
+                "Can't commit to same version: %s" % repr(src))
+
         if dest and abort:
-            raise 'VersionCommitError', (
-                'Internal error, can\'t abort to a version')
+            raise POSException.VersionCommitError(
+                "Internal error, can't abort to a version")
         
         if transaction is not self._transaction:
             raise POSException.StorageTransactionError(self, transaction)
@@ -501,7 +447,7 @@ class FileStorage(BaseStorage.BaseStorage,
                 h=read(58) # oid, serial, prev(oid), tloc, vlen, plen, pnv, pv
                 oid=h[:8]
                 pnv=h[-16:-8]
-                if index_get(oid, None) == srcpos:
+                if index_get(oid) == srcpos:
                     # This is a current record!
                     tindex[oid]=here
                     appoids(oid)
@@ -560,6 +506,31 @@ class FileStorage(BaseStorage.BaseStorage,
         if plen != z64: return read(U64(plen)), version, nv
         return _loadBack(file, oid, read(8))[0], version, nv
 
+    def getSerial(self, oid):
+        self._lock_acquire()
+        try:
+            pos = self._index[oid]
+            self._file.seek(pos)
+            h = self._file.read(34)
+            _oid = h[:8]
+            if _oid != oid:
+                raise CorruptedData, h
+            vlen = unpack(">H", h[-2:])[0]
+            if vlen:
+                # If there is a version, find out its name and let
+                # _load() do all the work.  This is less efficient
+                # than possible, because _load() will load the pickle
+                # data.  Being more efficient is too complicated.
+                self._file.seek(24, 1) # skip plen, pnv, and pv
+                version = self._file.read(vlen)
+                pickledata, serial = self._load(oid, version,
+                                                self._index, self._file)
+                return serial
+            return h[8:16]
+        finally:
+            self._lock_release()
+        
+
     def _load(self, oid, version, _index, file):
         pos=_index[oid]
         file.seek(pos)
@@ -723,7 +694,7 @@ class FileStorage(BaseStorage.BaseStorage,
             file=self._file
             write=file.write
             tfile.seek(0)
-            id=self._serial
+            tid=self._serial
             user, desc, ext = self._ude
             luser=len(user)
             ldesc=len(desc)
@@ -747,7 +718,7 @@ class FileStorage(BaseStorage.BaseStorage,
                 # suspect.
                 write(pack(
                     ">8s" "8s" "c"  "H"        "H"        "H"
-                     ,id, stl, 'c', luser,     ldesc,     lext,
+                     ,tid, stl, 'c', luser,     ldesc,     lext,
                     ))
                 if user: write(user)
                 if desc: write(desc)
@@ -785,7 +756,9 @@ class FileStorage(BaseStorage.BaseStorage,
             self._vindex.update(self._tvindex)
 
     def _abort(self):
-        if self._nextpos: self._file.truncate(self._nextpos)
+        if self._nextpos:
+            self._file.truncate(self._pos)
+            self._nextpos=0
 
     def undo(self, transaction_id):
         self._lock_acquire()
@@ -823,7 +796,7 @@ class FileStorage(BaseStorage.BaseStorage,
                 prev=U64(sprev)
                 dlen=42+(plen or 8)
                 if vlen: dlen=dlen+(16+vlen)
-                if index_get(oid,0) != pos: raise UndoError
+                if index_get(oid, 0) != pos: raise UndoError
                 pos=pos+dlen
                 if pos > tend: raise UndoError
                 t[oid]=prev
@@ -831,8 +804,7 @@ class FileStorage(BaseStorage.BaseStorage,
             seek(tpos+16)
             file.write('u')
             file.flush()
-            index=self._index
-            for oid, pos in t.items(): index[oid]=pos
+            self._index.update(t)
             return t.keys()            
         finally: self._lock_release()
 
@@ -898,7 +870,7 @@ class FileStorage(BaseStorage.BaseStorage,
         
         copy=1 # Can we just copy a data pointer
         tpos=self._tindex.get(oid, 0)        
-        ipos=self._index.get(oid,0)
+        ipos=self._index.get(oid, 0)
         tipos=tpos or ipos
         if tipos != pos:
             # Eek, a later transaction modified the data, but,
@@ -1187,6 +1159,7 @@ class FileStorage(BaseStorage.BaseStorage,
         finally: self._lock_release()
 
     def _redundant_pack(self, file, pos):
+        assert pos > 8, pos
         file.seek(pos-8)
         p=U64(file.read(8))
         file.seek(pos-p+8)
@@ -1236,6 +1209,8 @@ class FileStorage(BaseStorage.BaseStorage,
                 read_only=1,
                 )
 
+            if packpos == 4:
+                return
             if self._redundant_pack(file, packpos):
                 raise FileStorageError, (
                     'The database has already been packed to a later time\n'
@@ -1375,7 +1350,7 @@ class FileStorage(BaseStorage.BaseStorage,
 
                     if vlen:
                         dlen=dlen+(16+vlen)
-                        if packing and pindex_get(oid,0) != pos:
+                        if packing and pindex_get(oid, 0) != pos:
                             # This is not the most current record, or
                             # the oid is no longer referenced so skip it.
                             pos=pos+dlen
@@ -1452,7 +1427,7 @@ class FileStorage(BaseStorage.BaseStorage,
                                 # current record, then we should still
                                 # point at one, otherwise, we should
                                 # point at the last non-version record.
-                                ppos=pindex_get(oid,0)
+                                ppos=pindex_get(oid, 0)
                                 if ppos:
                                     if ppos==p:
                                         # we were pointing to the
@@ -1472,7 +1447,7 @@ class FileStorage(BaseStorage.BaseStorage,
                                 p=p-offset
                             p=p64(p)
                             
-                    sprev=p64(index_get(oid,0))
+                    sprev=p64(index_get(oid, 0))
                     write(pack(">8s8s8s8sH8s",
                                oid,serial,sprev,p64(otpos),vlen,splen))
                     if vlen:
@@ -1576,8 +1551,8 @@ class FileStorage(BaseStorage.BaseStorage,
             self._packt=z64
             _lock_release()
 
-    def iterator(self): return FileIterator(self._file_name)
-        
+    def iterator(self):
+        return FileIterator(self._file_name)
 
 def shift_transactions_forward(index, vindex, tindex, file, pos, opos):
     """Copy transactions forward in the data file
@@ -1663,12 +1638,12 @@ def shift_transactions_forward(index, vindex, tindex, file, pos, opos):
                 elif p >= p1:
                     # Ick, we're in trouble. Let's bail
                     # to the index and hope for the best
-                    p=index_get(oid,0)
+                    p=index_get(oid, 0)
                 p=p64(p)
 
             # WRITE
             seek(opos)
-            sprev=p64(index_get(oid,0))
+            sprev=p64(index_get(oid, 0))
             write(pack(">8s8s8s8sH8s",
                        oid,serial,sprev,p64(otpos),vlen,splen))
             if vlen:
@@ -1676,7 +1651,7 @@ def shift_transactions_forward(index, vindex, tindex, file, pos, opos):
                 else:
                     if pnv >= p2: pnv=pnv-offset
                     elif pnv >= p1:
-                        pnv=index_get(oid,0)
+                        pnv=index_get(oid, 0)
                         
                     write(p64(pnv))
                 write(pv)
@@ -1741,10 +1716,31 @@ def recover(file_name):
 
 def read_index(file, name, index, vindex, tindex, stop='\377'*8,
                ltid=z64, start=4L, maxoid=z64, recover=0, read_only=0):
+    """Scan the entire file storage and recreate the index.
+
+    Returns file position, max oid, and last transaction id.  It also
+    stores index information in the three dictionary arguments.
+
+    Arguments:
+    file -- a file object (the Data.fs)
+    name -- the name of the file (presumably file.name)
+    index -- dictionary, oid -> data record
+    vindex -- dictionary, oid -> data record for version data
+    tindex -- dictionary, oid -> data record
+       XXX tindex is cleared before return, so it will be empty
+
+    There are several default arguments that affect the scan or the
+    return values.  XXX should document them.
+
+    The file position returned is the position just after the last
+    valid transaction record.  The oid returned is the maximum object
+    id in the data.  The transaction id is the tid of the last
+    transaction. 
+    """
     
-    read=file.read
-    seek=file.seek
-    seek(0,2)
+    read = file.read
+    seek = file.seek
+    seek(0, 2)
     file_size=file.tell()
 
     if file_size:
@@ -1796,7 +1792,7 @@ def read_index(file, name, index, vindex, tindex, stop='\377'*8,
         if status not in ' up':
             warn('%s has invalid status, %s, at %s', name, status, pos)
 
-        if ul > tl or dl > tl or el > tl or tl < (23+ul+dl+el):
+        if tl < (23+ul+dl+el):
             # We're in trouble. Find out if this is bad data in the
             # middle of the file, or just a turd that Win 9x dropped
             # at the end when the system crashed.
@@ -1865,7 +1861,7 @@ def read_index(file, name, index, vindex, tindex, stop='\377'*8,
                 panic("%s data record exceeds transaction record at %s",
                       name, pos)
                 
-            if index_get(oid,0) != prev:
+            if index_get(oid, 0) != prev:
                 if prev:
                     if recover: return tpos, None, None
                     error("%s incorrect previous pointer at %s", name, pos)
@@ -1886,10 +1882,10 @@ def read_index(file, name, index, vindex, tindex, stop='\377'*8,
             panic("%s redundant transaction length check failed at %s",
                   name, pos)
         pos=pos+8
-        
-        for oid, p in tindex.items():
-            maxoid=max(maxoid,oid)
-            index[oid]=p # Record the position
+
+        _maxoid = max(tindex.keys()) # in 2.2, just max(tindex)
+        maxoid = max(_maxoid, maxoid)
+        index.update(tindex)
 
         tindex.clear()
 
@@ -1974,7 +1970,8 @@ class FileIterator(Iterator):
     _ltid=z64
     
     def __init__(self, file):
-        if type(file) is type(''): file=open(file, 'r+b')
+        if isinstance(file, StringType):
+            file=open(file, 'rb')
         self._file=file
         if file.read(4) != packed_version: raise FileStorageFormatError, name
         file.seek(0,2)
@@ -2013,7 +2010,7 @@ class FileIterator(Iterator):
             if status not in ' up':
                 warn('%s has invalid status, %s, at %s', name, status, pos)
 
-            if ul > tl or dl > tl or el > tl or tl < (23+ul+dl+el):
+            if tl < (23+ul+dl+el):
                 # We're in trouble. Find out if this is bad data in
                 # the middle of the file, or just a turd that Win 9x
                 # dropped at the end when the system crashed.  Skip to
@@ -2035,8 +2032,6 @@ class FileIterator(Iterator):
                     warn('%s has invalid transaction header at %s', name, pos)
                     break
 
-            # if tid >= stop: raise IndexError, index
-
             tpos=pos
             tend=tpos+tl
 
