@@ -1,91 +1,19 @@
 /*****************************************************************************
+
+  Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
   
-  Zope Public License (ZPL) Version 1.0
-  -------------------------------------
-  
-  Copyright (c) Digital Creations.  All rights reserved.
-  
-  This license has been certified as Open Source(tm).
-  
-  Redistribution and use in source and binary forms, with or without
-  modification, are permitted provided that the following conditions are
-  met:
-  
-  1. Redistributions in source code must retain the above copyright
-     notice, this list of conditions, and the following disclaimer.
-  
-  2. Redistributions in binary form must reproduce the above copyright
-     notice, this list of conditions, and the following disclaimer in
-     the documentation and/or other materials provided with the
-     distribution.
-  
-  3. Digital Creations requests that attribution be given to Zope
-     in any manner possible. Zope includes a "Powered by Zope"
-     button that is installed by default. While it is not a license
-     violation to remove this button, it is requested that the
-     attribution remain. A significant investment has been put
-     into Zope, and this effort will continue if the Zope community
-     continues to grow. This is one way to assure that growth.
-  
-  4. All advertising materials and documentation mentioning
-     features derived from or use of this software must display
-     the following acknowledgement:
-  
-       "This product includes software developed by Digital Creations
-       for use in the Z Object Publishing Environment
-       (http://www.zope.org/)."
-  
-     In the event that the product being advertised includes an
-     intact Zope distribution (with copyright and license included)
-     then this clause is waived.
-  
-  5. Names associated with Zope or Digital Creations must not be used to
-     endorse or promote products derived from this software without
-     prior written permission from Digital Creations.
-  
-  6. Modified redistributions of any form whatsoever must retain
-     the following acknowledgment:
-  
-       "This product includes software developed by Digital Creations
-       for use in the Z Object Publishing Environment
-       (http://www.zope.org/)."
-  
-     Intact (re-)distributions of any official Zope release do not
-     require an external acknowledgement.
-  
-  7. Modifications are encouraged but must be packaged separately as
-     patches to official Zope releases.  Distributions that do not
-     clearly separate the patches from the original work must be clearly
-     labeled as unofficial distributions.  Modifications which do not
-     carry the name Zope may be packaged in any form, as long as they
-     conform to all of the clauses above.
-  
-  
-  Disclaimer
-  
-    THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
-    EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-    IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-    PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
-    CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-    SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-    LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-    USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-    ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-    OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
-    OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-    SUCH DAMAGE.
-  
-  
-  This software consists of contributions made by Digital Creations and
-  many individuals on behalf of Digital Creations.  Specific
-  attributions are listed in the accompanying credits file.
+  This software is subject to the provisions of the Zope Public License,
+  Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
+  THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
+  WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+  WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
+  FOR A PARTICULAR PURPOSE
   
  ****************************************************************************/
 static char cPersistence_doc_string[] = 
 "Defines Persistent mixin class for persistent objects.\n"
 "\n"
-"$Id: cPersistence.c,v 1.43 2001/03/28 14:04:15 jim Exp $\n";
+"$Id: cPersistence.c,v 1.47 2001/11/28 15:51:20 matt Exp $\n";
 
 #include <string.h>
 #include "cPersistence.h"
@@ -137,6 +65,20 @@ init_strings(void)
   return 0;
 }
 
+static int
+checknoargs(PyObject *args)
+{
+  if (!PyTuple_Check(args))
+    return 0;
+  if (PyTuple_GET_SIZE(args) != 0) {
+    PyErr_Format(PyExc_TypeError, 
+		 "function takes exactly 0 arguments (%d given)",
+		 PyTuple_GET_SIZE(args));
+    return 0;
+  }
+  return 1;
+}
+
 static PyObject *
 callmethod(PyObject *self, PyObject *name)
 {
@@ -149,13 +91,18 @@ callmethod(PyObject *self, PyObject *name)
 static PyObject *
 callmethod1(PyObject *self, PyObject *name, PyObject *arg)
 {
-  if((self=PyObject_GetAttr(self,name)) && (name=PyTuple_New(1)))
+  self = PyObject_GetAttr(self, name);
+  UNLESS(self) return NULL;
+  name = PyTuple_New(1);
+  UNLESS(name) 
     {
-      PyTuple_SET_ITEM(name, 0, arg);
-      ASSIGN(self,PyObject_CallObject(self,name));
-      PyTuple_SET_ITEM(name, 0, NULL);
-      Py_DECREF(name);
+      Py_DECREF(self);
+      return NULL;
     }
+  PyTuple_SET_ITEM(name, 0, arg);
+  ASSIGN(self, PyObject_CallObject(self, name));
+  PyTuple_SET_ITEM(name, 0, NULL);
+  Py_DECREF(name);
   return self;
 }
 
@@ -243,7 +190,8 @@ Per__p_deactivate(cPersistentObject *self, PyObject *args)
   if (idebug_log < 0) call_debug("reinit",self);
 #endif
 
-  if (args && ! PyArg_ParseTuple(args,"")) return NULL;
+  if (args && !checknoargs(args))
+    return NULL;
 
   if (self->state==cPersistent_UPTODATE_STATE && self->jar &&
       HasInstDict(self) && (dict=INSTANCE_DICT(self)))
@@ -273,7 +221,7 @@ Per__getstate__(cPersistentObject *self, PyObject *args)
 {
   PyObject *__dict__, *d=0;
 
-  UNLESS(PyArg_ParseTuple(args, "")) return NULL;
+  if (!checknoargs(args)) return NULL;
 
 #ifdef DEBUG_LOG
   if(idebug_log < 0) call_debug("get",self);
@@ -289,12 +237,12 @@ Per__getstate__(cPersistentObject *self, PyObject *args)
 	  
       for(pos=0; PyDict_Next(__dict__, &pos, &k, &v); )
 	{
-	  if(PyString_Check(k) && (ck=PyString_AsString(k)) &&
+	  if(PyString_Check(k) && (ck=PyString_AS_STRING(k)) &&
 	     (*ck=='_' && ck[1]=='v' && ck[2]=='_'))
 	    {
 	      UNLESS(d=PyDict_New()) goto err;
 	      for(pos=0; PyDict_Next(__dict__, &pos, &k, &v); )
-		UNLESS(PyString_Check(k) && (ck=PyString_AsString(k)) &&
+		UNLESS(PyString_Check(k) && (ck=PyString_AS_STRING(k)) &&
 		       (*ck=='_' && ck[1]=='v' && ck[2]=='_'))
 		  if(PyDict_SetItem(d,k,v) < 0) goto err;
 	      return d;
@@ -331,8 +279,8 @@ Per__setstate__(cPersistentObject *self, PyObject *args)
 	   
 	   if(PyDict_Check(v))
 	     {
-	       for(i=0; PyDict_Next(v,&i,&key,&e);)
-		 if(PyObject_SetItem(__dict__,key,e) < 0)
+	       for(i=0; PyDict_Next(v, &i, &key, &e);)
+		 if(PyDict_SetItem(__dict__, key, e) < 0)
 		   return NULL;
 	     }
 	   else
@@ -344,7 +292,7 @@ Per__setstate__(cPersistentObject *self, PyObject *args)
 		 {
 		   UNLESS_ASSIGN(key,PySequence_GetItem(keys,i)) goto err;
 		   UNLESS_ASSIGN(e,PyObject_GetItem(v,key)) goto err;
-		   UNLESS(-1 != PyObject_SetItem(__dict__,key,e)) goto err;
+		   UNLESS(-1 != PyDict_SetItem(__dict__,key,e)) goto err;
 		 }
 	       
 	       Py_XDECREF(key);
@@ -483,7 +431,7 @@ Per_getattro(cPersistentObject *self, PyObject *name)
   PyObject *r;
 
   if (PyString_Check(name))
-    UNLESS(s=PyString_AsString(name)) return NULL;
+    UNLESS(s=PyString_AS_STRING(name)) return NULL;
 
   r = Per_getattr(self, name, s, PyExtensionClassCAPI->getattro);
   if (! r && self->state != cPersistent_GHOST_STATE &&
@@ -492,6 +440,7 @@ Per_getattro(cPersistentObject *self, PyObject *name)
       )
     {
       PyErr_Clear();
+
       r=PyObject_GetAttr(OBJECT(self), py___getattr__);
       if (r) 
 	{
@@ -510,7 +459,7 @@ _setattro(cPersistentObject *self, PyObject *oname, PyObject *v,
   char *name="";
 
   UNLESS(oname) return -1;
-  if(PyString_Check(oname)) UNLESS(name=PyString_AsString(oname)) return -1;
+  if(PyString_Check(oname)) UNLESS(name=PyString_AS_STRING(oname)) return -1;
 	
   if(*name=='_' && name[1]=='p' && name[2]=='_')
     {
@@ -739,7 +688,7 @@ void
 initcPersistence(void)
 {
   PyObject *m, *d, *s;
-  char *rev="$Revision: 1.43 $";
+  char *rev="$Revision: 1.47 $";
 
   s = PyString_FromString("TimeStamp");
   if (s == NULL)
@@ -751,9 +700,7 @@ initcPersistence(void)
   }
   TimeStamp = PyObject_GetAttr(m, s);
   Py_DECREF(m);
-  if (TimeStamp == NULL) {
-      Py_DECREF(s);
-  }
+  Py_DECREF(s);
 
   if (init_strings() < 0) return;
 
@@ -762,12 +709,19 @@ initcPersistence(void)
 
   
   d = PyModule_GetDict(m);
-  PyDict_SetItemString(d,"__version__",
-		       PyString_FromStringAndSize(rev+11,strlen(rev+11)-2));
+  s = PyString_FromStringAndSize(rev+11,strlen(rev+11)-2);
+  PyDict_SetItemString(d,"__version__", s);
+  Py_XDECREF(s);
+
   PyExtensionClass_Export(d, "Persistent",  Pertype);
   PyExtensionClass_Export(d, "Overridable", Overridable);
 
   cPersistenceCAPI=&truecPersistenceCAPI;
-  PyDict_SetItemString(d, "CAPI",
-		       PyCObject_FromVoidPtr(cPersistenceCAPI,NULL));
+  s = PyCObject_FromVoidPtr(cPersistenceCAPI,NULL);
+  PyDict_SetItemString(d, "CAPI", s);
+  Py_XDECREF(s);
+
+  /* Check for errors */
+  if (PyErr_Occurred())
+    Py_FatalError("can't initialize module cPersistence");
 }
