@@ -1,98 +1,27 @@
 ##############################################################################
+#
+# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
 # 
-# Zope Public License (ZPL) Version 1.0
-# -------------------------------------
-# 
-# Copyright (c) Digital Creations.  All rights reserved.
-# 
-# This license has been certified as Open Source(tm).
-# 
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions are
-# met:
-# 
-# 1. Redistributions in source code must retain the above copyright
-#    notice, this list of conditions, and the following disclaimer.
-# 
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions, and the following disclaimer in
-#    the documentation and/or other materials provided with the
-#    distribution.
-# 
-# 3. Digital Creations requests that attribution be given to Zope
-#    in any manner possible. Zope includes a "Powered by Zope"
-#    button that is installed by default. While it is not a license
-#    violation to remove this button, it is requested that the
-#    attribution remain. A significant investment has been put
-#    into Zope, and this effort will continue if the Zope community
-#    continues to grow. This is one way to assure that growth.
-# 
-# 4. All advertising materials and documentation mentioning
-#    features derived from or use of this software must display
-#    the following acknowledgement:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    In the event that the product being advertised includes an
-#    intact Zope distribution (with copyright and license included)
-#    then this clause is waived.
-# 
-# 5. Names associated with Zope or Digital Creations must not be used to
-#    endorse or promote products derived from this software without
-#    prior written permission from Digital Creations.
-# 
-# 6. Modified redistributions of any form whatsoever must retain
-#    the following acknowledgment:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    Intact (re-)distributions of any official Zope release do not
-#    require an external acknowledgement.
-# 
-# 7. Modifications are encouraged but must be packaged separately as
-#    patches to official Zope releases.  Distributions that do not
-#    clearly separate the patches from the original work must be clearly
-#    labeled as unofficial distributions.  Modifications which do not
-#    carry the name Zope may be packaged in any form, as long as they
-#    conform to all of the clauses above.
-# 
-# 
-# Disclaimer
-# 
-#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
-#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
-#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
-#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-#   SUCH DAMAGE.
-# 
-# 
-# This software consists of contributions made by Digital Creations and
-# many individuals on behalf of Digital Creations.  Specific
-# attributions are listed in the accompanying credits file.
+# This software is subject to the provisions of the Zope Public License,
+# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
+# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
+# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
+# FOR A PARTICULAR PURPOSE
 # 
 ##############################################################################
 '''CGI Response Output formatter
 
-$Id: HTTPResponse.py,v 1.46.20.2 2001/08/07 18:32:50 evan Exp $'''
-__version__='$Revision: 1.46.20.2 $'[11:-2]
+$Id: HTTPResponse.py,v 1.53 2002/01/02 15:56:04 andreasjung Exp $'''
+__version__='$Revision: 1.53 $'[11:-2]
 
-import string, types, sys,  re
-from string import find, rfind, lower, upper, strip, split, join, translate
+import  types, sys,  re
+from string import translate, maketrans
 from types import StringType, InstanceType, LongType
 from BaseResponse import BaseResponse
+from zExceptions import Unauthorized
 
-nl2sp=string.maketrans('\n',' ')
+nl2sp=maketrans('\n',' ')
 
 status_reasons={
 100: 'Continue',
@@ -147,13 +76,13 @@ status_codes={}
 # Add mappings for builtin exceptions and
 # provide text -> error code lookups.
 for key, val in status_reasons.items():
-    status_codes[lower(join(split(val, ' '), ''))]=key
-    status_codes[lower(val)]=key
+    status_codes[''.join(val.split(' ')).lower()]=key
+    status_codes[val.lower()]=key
     status_codes[key]=key
     status_codes[str(key)]=key
 en=filter(lambda n: n[-5:]=='Error', dir(__builtins__))
-for name in map(lower, en):
-    status_codes[name]=500
+for name in en:
+    status_codes[name.lower()]=500
 status_codes['nameerror']=503
 status_codes['keyerror']=503
 status_codes['redirect']=300
@@ -236,7 +165,7 @@ class HTTPResponse(BaseResponse):
             return
                 
         if type(status) is types.StringType:
-            status=lower(status)
+            status=status.lower()
         if status_codes.has_key(status): status=status_codes[status]
         else: status=500
         self.status=status
@@ -253,7 +182,7 @@ class HTTPResponse(BaseResponse):
         literal flag is true, the case of the header name is preserved,
         otherwise word-capitalization will be performed on the header
         name on output.'''
-        key=lower(name)
+        key=name.lower()
         if accumulate_header(key):
             self.accumulated_headers=(
                 "%s%s: %s\n" % (self.accumulated_headers, name, value))
@@ -303,7 +232,7 @@ class HTTPResponse(BaseResponse):
 
         body=str(body)
         l=len(body)
-        if ((l < 200) and body[:1]=='<' and find(body,'>')==l-1 and 
+        if ((l < 200) and body[:1]=='<' and body.find('>')==l-1 and 
             bogus_str_search(body) is not None):
             self.notFoundError(body[1:-1])
         else:
@@ -329,8 +258,8 @@ class HTTPResponse(BaseResponse):
         content_type=self.headers['content-type']
         if content_type == 'text/html' or latin1_alias_match(
             content_type) is not None:
-            body = join(split(body,'\213'),'&lt;')
-            body = join(split(body,'\233'),'&gt;')
+            body = '&lt;'.join(body.split('\213'))
+            body = '&gt;'.join(body.split('\233'))
 
         self.setHeader('content-length', len(self.body))
         self.insertBase()
@@ -347,7 +276,7 @@ class HTTPResponse(BaseResponse):
                    ):
 
         # Only insert a base tag if content appears to be html.
-        content_type = split(self.headers.get('content-type', ''), ';')[0]
+        content_type = self.headers.get('content-type', '').split(';')[0]
         if content_type and (content_type != 'text/html'):
             return
 
@@ -426,19 +355,19 @@ class HTTPResponse(BaseResponse):
         self.setHeader(name,h)
 
     def isHTML(self,str):
-        return lower(strip(str)[:6]) == '<html>' or find(str,'</') > 0
+        return str.strip().lower()[:6] == '<html>' or str.find('</') > 0
 
     def quoteHTML(self,text,
                   subs={'&':'&amp;', "<":'&lt;', ">":'&gt;', '\"':'&quot;'}
                   ):
         for ent in '&<>\"':
-            if find(text, ent) >= 0:
-                text=join(split(text,ent),subs[ent])
+            if text.find( ent) >= 0:
+                text=subs[ent].join(text.split(ent))
 
         return text
          
 
-    def format_exception(self,etype,value,tb,limit=None):
+    def format_exception(self, etype, value, tb, limit=None):
         import traceback
         result=['Traceback (innermost last):']
         if limit is None:
@@ -461,17 +390,18 @@ class HTTPResponse(BaseResponse):
                                    str(locals['__traceback_info__']))
                 except: pass
                 tb = tb.tb_next
-                n = n+1
-        result.append(join(traceback.format_exception_only(etype, value),
-                           ' '))
+                n = n + 1
+        result.append(' '.join(traceback.format_exception_only(etype, value)))
         return result
 
-    def _traceback(self,t,v,tb):
-        tb=self.format_exception(t,v,tb,200)
-        tb=join(tb,'\n')
-        tb=self.quoteHTML(tb)
+    def _traceback(self, t, v, tb):
+        tb = self.format_exception(t, v, tb, 200)
+        tb = '\n'.join(tb)
+        tb = self.quoteHTML(tb)
         if self.debug_mode: _tbopen, _tbclose = '<PRE>', '</PRE>'
-        else:               _tbopen, _tbclose = '<!--',  '-->'
+        else:               _tbopen, _tbclose = '''<pre
+          onclick="this.firstChild.data=this.lastChild.data">
+        &sect;<!--''',  '--></pre>'
         return "\n%s\n%s\n%s" % (_tbopen, tb, _tbclose)
 
     def redirect(self, location, status=302, lock=0):
@@ -578,91 +508,98 @@ class HTTPResponse(BaseResponse):
                 m=m+'<p>\nUsername and password are not correct.'
             else:
                 m=m+'<p>\nNo Authorization header found.'
-        raise 'Unauthorized', m
+        raise Unauthorized, m
 
     def exception(self, fatal=0, info=None,
                   absuri_match=re.compile(r'\w+://[\w\.]+').match,
                   tag_search=re.compile('[a-zA-Z]>').search,
                   abort=1
                   ):
-        if type(info) is type(()) and len(info)==3: t,v,tb = info
-        else: t,v,tb = sys.exc_info()
+        if type(info) is type(()) and len(info)==3:
+            t, v, tb = info
+        else:
+            t, v, tb = sys.exc_info()
 
-        if str(t)=='Unauthorized': self._unauthorized()
+        if t == 'Unauthorized' or t == Unauthorized or (
+            isinstance(t, types.ClassType) and issubclass(t, Unauthorized)):
+            t = 'Unauthorized'
+            self._unauthorized()
 
-        stb=tb
+        stb = tb # note alias between tb and stb
 
         try:
             # Try to capture exception info for bci calls
-            et=translate(str(t),nl2sp)
-            self.setHeader('bobo-exception-type',et)
-            ev=translate(str(v),nl2sp)
-            if find(ev,'<html>') >= 0: ev='bobo exception'
-            self.setHeader('bobo-exception-value',ev[:255])
+            et = translate(str(t), nl2sp)
+            self.setHeader('bobo-exception-type', et)
+            ev = translate(str(v), nl2sp)
+            if ev.find( '<html>') >= 0:
+                ev = 'bobo exception'
+            self.setHeader('bobo-exception-value', ev[:255])
             # Get the tb tail, which is the interesting part:
-            while tb.tb_next is not None: tb=tb.tb_next
-            el=str(tb.tb_lineno)
-            ef=str(tb.tb_frame.f_code.co_filename)
-            self.setHeader('bobo-exception-file',ef)
-            self.setHeader('bobo-exception-line',el)
+            while tb.tb_next is not None:
+                tb = tb.tb_next
+            el = str(tb.tb_lineno)
+            ef = str(tb.tb_frame.f_code.co_filename)
+            self.setHeader('bobo-exception-file', ef)
+            self.setHeader('bobo-exception-line', el)
 
         except:
             # Dont try so hard that we cause other problems ;)
             pass
 
-        tb=stb
-        stb=None
+        tb = stb # original traceback
+        del stb
         self.setStatus(t)
         if self.status >= 300 and self.status < 400:
             if type(v) == types.StringType and absuri_match(v) is not None:
-                if self.status==300: self.setStatus(302)
+                if self.status==300:
+                    self.setStatus(302)
                 self.setHeader('location', v)
-                tb=None
+                tb = None # just one path covered
                 return self
             else:
                 try:
-                    l,b=v
-                    if type(l) == types.StringType and absuri_match(l) is not None:
-                        if self.status==300: self.setStatus(302)
+                    l, b = v
+                    if (type(l) == types.StringType
+                        and absuri_match(l) is not None):
+                        if self.status==300:
+                            self.setStatus(302)
                         self.setHeader('location', l)
                         self.setBody(b)
-                        tb=None
+                        tb = None # one more patch covered
                         return self
-                except: pass
+                except:
+                    pass # tb is not cleared in this case
 
-        b=v
-        if isinstance(b,Exception):
+        b = v
+        if isinstance(b, Exception):
             try:
-                b=str(b)
+                b = str(b)
             except:
-                b='<unprintable %s object>' % type(b).__name__
-        
-        if fatal and t is SystemExit and v.code==0:
-                tb=self.setBody(
-                    (str(t),
-                    'Zope has exited normally.<p>'
-                     + self._traceback(t,v,tb)),
-                     is_error=1)
-        #elif 1: self.setBody(v)
+                b = '<unprintable %s object>' % type(b).__name__
 
-        elif type(b) is not types.StringType or tag_search(b) is None:
-            tb=self.setBody(
+        if fatal and t is SystemExit and v.code == 0:
+            body = self.setBody(
                 (str(t),
-                'Sorry, a site error occurred.<p>'+
-                 self._traceback(t,v,tb)),
-                 is_error=1)
-
-        elif (lower(strip(b)[:6])=='<html>' or
-              lower(strip(b)[:14])=='<!doctype html'):
-            # error is an HTML document, not just a snippet of html
-            tb=self.setBody(b + self._traceback(t,'(see above)',tb),
+                 'Zope has exited normally.<p>' + self._traceback(t, v, tb)),
                 is_error=1)
-        else:
-            tb=self.setBody(
-                (str(t), b + self._traceback(t,'(see above)',tb)),
+        elif type(b) is not types.StringType or tag_search(b) is None:
+            body = self.setBody(
+                (str(t),
+                'Sorry, a site error occurred.<p>'
+                 + self._traceback(t, v, tb)),
                  is_error=1)
-
-        return tb
+        elif b.strip().lower()[:6]=='<html>' or \
+              b.strip().lower()[:14]=='<!doctype html':
+            # error is an HTML document, not just a snippet of html
+            body = self.setBody(b + self._traceback(t, '(see above)', tb),
+                              is_error=1)
+        else:
+            body = self.setBody((str(t),
+                               b + self._traceback(t,'(see above)', tb)),
+                              is_error=1)
+        del tb
+        return body
 
     _wrote=None
 
@@ -676,7 +613,7 @@ class HTTPResponse(BaseResponse):
 
             cookie='Set-Cookie: %s="%s"' % (name, attrs['value'])
             for name, v in attrs.items():
-                name=lower(name)
+                name=name.lower()
                 if name=='expires': cookie = '%s; Expires=%s' % (cookie,v)
                 elif name=='domain': cookie = '%s; Domain=%s' % (cookie,v)
                 elif name=='path': cookie = '%s; Path=%s' % (cookie,v)
@@ -720,20 +657,20 @@ class HTTPResponse(BaseResponse):
         if headers.has_key('status'):
             del headers['status']
         for key, val in headers.items():
-            if lower(key)==key:
+            if key.lower()==key:
                 # only change non-literal header names
-                key="%s%s" % (upper(key[:1]), key[1:])
+                key="%s%s" % (key[:1].upper(), key[1:])
                 start=0
-                l=find(key,'-',start)
+                l=key.find('-',start)
                 while l >= start:
-                    key="%s-%s%s" % (key[:l],upper(key[l+1:l+2]),key[l+2:])
+                    key="%s-%s%s" % (key[:l],key[l+1:l+2].upper(),key[l+2:])
                     start=l+1
-                    l=find(key,'-',start)
+                    l=key.find('-',start)
             append("%s: %s" % (key, val))
         if self.cookies:
             headersl=headersl+self._cookie_list()
         headersl[len(headersl):]=[self.accumulated_headers, body]
-        return join(headersl,'\n')
+        return '\n'.join(headersl)
 
     def write(self,data):
         """\
