@@ -1,94 +1,23 @@
 #!/usr/bin/env python
+
 ##############################################################################
+#
+# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
 # 
-# Zope Public License (ZPL) Version 1.0
-# -------------------------------------
-# 
-# Copyright (c) Digital Creations.  All rights reserved.
-# 
-# This license has been certified as Open Source(tm).
-# 
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions are
-# met:
-# 
-# 1. Redistributions in source code must retain the above copyright
-#    notice, this list of conditions, and the following disclaimer.
-# 
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions, and the following disclaimer in
-#    the documentation and/or other materials provided with the
-#    distribution.
-# 
-# 3. Digital Creations requests that attribution be given to Zope
-#    in any manner possible. Zope includes a "Powered by Zope"
-#    button that is installed by default. While it is not a license
-#    violation to remove this button, it is requested that the
-#    attribution remain. A significant investment has been put
-#    into Zope, and this effort will continue if the Zope community
-#    continues to grow. This is one way to assure that growth.
-# 
-# 4. All advertising materials and documentation mentioning
-#    features derived from or use of this software must display
-#    the following acknowledgement:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    In the event that the product being advertised includes an
-#    intact Zope distribution (with copyright and license included)
-#    then this clause is waived.
-# 
-# 5. Names associated with Zope or Digital Creations must not be used to
-#    endorse or promote products derived from this software without
-#    prior written permission from Digital Creations.
-# 
-# 6. Modified redistributions of any form whatsoever must retain
-#    the following acknowledgment:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    Intact (re-)distributions of any official Zope release do not
-#    require an external acknowledgement.
-# 
-# 7. Modifications are encouraged but must be packaged separately as
-#    patches to official Zope releases.  Distributions that do not
-#    clearly separate the patches from the original work must be clearly
-#    labeled as unofficial distributions.  Modifications which do not
-#    carry the name Zope may be packaged in any form, as long as they
-#    conform to all of the clauses above.
-# 
-# 
-# Disclaimer
-# 
-#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
-#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
-#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
-#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-#   SUCH DAMAGE.
-# 
-# 
-# This software consists of contributions made by Digital Creations and
-# many individuals on behalf of Digital Creations.  Specific
-# attributions are listed in the accompanying credits file.
+# This software is subject to the provisions of the Zope Public License,
+# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
+# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
+# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
+# FOR A PARTICULAR PURPOSE
 # 
 ##############################################################################
 
 """ Request log profiler script """
 
-__version__='$Revision: 1.5.4.2 $'[11:-2]
+__version__='$Revision: 1.14 $'[11:-2]
 
-import string, sys, time, getopt, tempfile
+import string, sys, time, getopt, tempfile, math, cPickle
 
 class ProfileException(Exception): pass
 
@@ -104,7 +33,7 @@ class Request:
         self.httpcode = None
         self.t_end = None
         self.elapsed = "I"
-        self.active = "NA"
+        self.active = 0
         
     def put(self, code, t, desc):
         if code not in ('A', 'B', 'I', 'E'):
@@ -131,6 +60,13 @@ class Request:
             return time.strftime('%Y-%m-%dT%H:%M:%S', t)
         else:
             return "NA"
+
+    def shortprettystart(self):
+        if self.start is not None:
+            t = time.localtime(self.start)
+            return time.strftime('%H:%M:%S', t)
+        else:
+            return "NA"
         
     def win(self):
         if self.t_recdinput is not None and self.start is not None:
@@ -201,6 +137,12 @@ class Request:
                 'Code', 'Act', 'URL')
         return self.fmt % body
 
+class StartupRequest(Request):
+    def endstage(self):
+        return "U"
+        
+    def total(self):
+        return 0
 
 class Cumulative:
     def __init__(self, url):
@@ -290,16 +232,16 @@ def parsebigmlogline(line):
     else:
         return None
 
-def analyze(f, top, sortf, start=None, end=None, mode='cumulative'):
-    beginrequests = {}
-    cumulative = {}
-    finished = []
-    unfinished = {}
-    
-    while 1:
-        line = f.readline()
+def get_earliest_file_data(files):
+    temp = {}
+    earliest_fromepoch = 0
+    earliest = None
+    retn = None
+    for file in files:
+        line = file.readline()
         if not line:
-            break
+            continue
+        linelen = len(line)
         line = string.strip(line)
         tup = parsebigmlogline(line)
         if tup is None:
@@ -308,23 +250,79 @@ def analyze(f, top, sortf, start=None, end=None, mode='cumulative'):
         code, id, timestr, desc = tup
         timestr = string.strip(timestr)
         fromepoch = getdate(timestr)
-        if start is not None and fromepoch < start: continue
-        if end is not None and fromepoch > end: break
-        request = unfinished.get(id)
-        if request is None:
-            if code != "B": continue # garbage at beginning of file
-            request = Request()
-            unfinished[id] = request
-        request.put(code, int(fromepoch), desc)
-        if request.isfinished():
-            del unfinished[id]
-            finished.append(request)
-            request.active = len(unfinished)
-            
-    finished.extend(unfinished.values())
-    requests = finished
+        temp[file] = linelen
+        if earliest_fromepoch == 0 or fromepoch < earliest_fromepoch:
+            earliest_fromepoch = fromepoch
+            earliest = file
+            retn = [code, id, fromepoch, desc]
+
+    for file, linelen in temp.items():
+        if file is not earliest:
+            file.seek(file.tell() - linelen)
+
+    return retn
+
+def get_requests(files, start=None, end=None, statsfname=None,
+                 writestats=None, readstats=None):
+    finished = []
+    unfinished = {}
+    if readstats:
+        fp = open(statsfname, 'r')
+        u = cPickle.Unpickler(fp)
+        requests = u.load()
+        fp.close()
+        del u
+        del fp
+    else:
+        while 1:
+            tup = get_earliest_file_data(files)
+            if tup is None:
+                break
+            code, id, fromepoch, desc = tup
+            if start is not None and fromepoch < start: continue
+            if end is not None and fromepoch > end: break
+            if code == 'U':
+                finished.extend(unfinished.values())
+                unfinished.clear()
+                request = StartupRequest()
+                request.url = desc
+                request.start = int(fromepoch)
+                finished.append(request)
+                continue
+            request = unfinished.get(id)
+            if request is None:
+                if code != "B": continue # garbage at beginning of file
+                request = Request()
+                for pending_req in unfinished.values():
+                    pending_req.active = pending_req.active + 1
+                unfinished[id] = request
+            t = int(fromepoch)
+            try:
+                request.put(code, t, desc)
+            except:
+                print "Unable to handle entry: %s %s %s"%(code, t, desc)
+            if request.isfinished():
+                del unfinished[id]
+                finished.append(request)
+
+        finished.extend(unfinished.values())
+        requests = finished
+
+        if writestats:
+            fp = open(statsfname, 'w')
+            p = cPickle.Pickler(fp)
+            p.dump(requests)
+            fp.close()
+            del p
+            del fp
+
+    return requests
+
+def analyze(requests, top, sortf, start=None, end=None, mode='cumulative',
+            resolution=60, urlfocusurl=None, urlfocustime=60):
 
     if mode == 'cumulative':
+        cumulative = {}
         for request in requests:
             url = request.url
             stats = cumulative.get(url)
@@ -332,19 +330,85 @@ def analyze(f, top, sortf, start=None, end=None, mode='cumulative'):
                 stats = Cumulative(url)
                 cumulative[url] = stats
             stats.put(request)
+        requests = cumulative.values()
+        requests.sort(sortf)
+        write(requests, top)
+        
+    elif mode=='timed':
+        computed_start = requests[0].start
+        computed_end = requests[-1].t_end
+        if start and end:
+            timewrite(requests,start,end,resolution)
+        if start and not end:
+            timewrite(requests,start,computed_end,resolution)
+        if end and not start:
+            timewrite(requests,computed_start,end,resolution)
+        if not end and not start:
+            timewrite(requests,computed_start,computed_end,resolution)
 
-    cumulative = cumulative.values()
+    elif mode == 'urlfocus':
+        requests.sort(sortf)
+        urlfocuswrite(requests, urlfocusurl, urlfocustime)
     
-    if mode == 'cumulative':
-        dict = cumulative
-    elif mode == 'detailed':
-        dict = requests
     else:
-        raise "Invalid mode."
+        requests.sort(sortf)
+        write(requests, top)
+
+def urlfocuswrite(requests, url, t):
+    l = []
+    i = 0
+    for request in requests:
+        if request.url == url: l.append(i)
+        i = i + 1
+    before = {}
+    after = {}
+    x = 0
+    for n in l:
+        x = x + 1
+        r = requests[n]
+        start = r.start
+        earliest = start - t
+        latest = start + t
+        print 'URLs invoked %s seconds before and after %s (#%s, %s)' % \
+              (t, url, x, r.shortprettystart())
+        print '---'
+        i = -1
+        for request in requests:
+            i = i + 1
+            if request.start < earliest: continue
+            if request.start > latest: break
+            if n == i: # current request
+                print '%3d' % (request.start - start),
+                print '%s' % (request.shortprettystart()),
+                print request.url
+                continue
+            if request.start <= start:
+                if before.get(i):
+                    before[i] = before[i] + 1
+                else:
+                    before[i] = 1
+            if request.start > start:
+                if after.get(i):
+                    after[i] = after[i] + 1
+                else:
+                    after[i] = 1
+            print '%3d' % (request.start - start),
+            print '%s' % (request.shortprettystart()),
+            print request.url
+        print
+    print ('Summary of URLs invoked before (and at the same time as) %s '
+           '(times, url)' % url)
+    before = before.items()
+    before.sort()
+    for k,v in before:
+        print v, requests[k].url
+    print
+    print 'Summary of URLs invoked after %s (times, url)' % url
+    after = after.items()
+    after.sort()
+    for k,v in after:
+        print v, requests[k].url
 
-    dict.sort(sortf)
-    write(dict, top)
-    
 def write(requests, top=0):
     if len(requests) == 0:
         print "No data.\n"
@@ -370,6 +434,61 @@ def getdate(val):
         return t
     except:
         raise ProfileException, "bad date %s" % val
+
+def getTimeslice(period, utime):
+    low = int(math.floor(utime)) - period + 1
+    high = int(math.ceil(utime)) + 1
+    for x in range(low, high):
+        if x % period == 0:
+            return x
+
+def timewrite(requests, start, end, resolution):
+    print "Start: %s    End: %s   Resolution: %d secs" % \
+        (tick2str(start), tick2str(end), resolution)
+    print "-" * 78
+    print
+    print "Date/Time                #requests requests/second"
+
+    d = {}
+    max = 0
+    min = None
+    for r in requests:
+        t = r.start
+        slice = getTimeslice(resolution,t)
+        if slice > max: max = slice
+        if (min is None) or (slice < min): min = slice
+        if d.has_key(slice):
+            d[slice] = d[slice] + 1
+        else:
+            d[slice] = 1
+
+    num = 0
+    hits = 0
+    avg_requests = None
+    max_requests = 0
+    for slice in range(min, max, resolution):
+        num = d.get(slice, 0)
+        if num>max_requests: max_requests = num
+        hits = hits + num
+        
+        if avg_requests is None:
+            avg_requests = num
+        else:
+            avg_requests = (avg_requests + num) / 2
+
+        s = tick2str(slice)
+        s = s + "     %6d         %4.2lf" % (num,num*1.0/resolution)
+        print s 
+
+    print '='*78 
+    print " Peak:                  %6d         %4.2lf" % \
+        (max_requests,max_requests*1.0/resolution)
+    print "  Avg:                  %6d         %4.2lf" % \
+        (avg_requests,avg_requests*1.0/resolution)
+    print "Total:                  %6d          n/a " % (hits)
+    
+def tick2str(t):
+    return time.strftime('%Y-%m-%dT%H:%M:%S', time.localtime(t))
     
 def codesort(v1, v2):
     v1 = v1.endstage()
@@ -411,16 +530,34 @@ def detailedusage():
     details = usage(0)
     pname = sys.argv[0]
     details = details + """
-Reports are of two types: cumulative or detailed.  The default is cumulative.
-Data is taken from the Zope detailed request log (the -M log).
+Reports are of four types: cumulative, detailed, timed, or urlfocus.  The
+default is cumulative. Data is taken from one or more Zope detailed request
+logs (-M logs, aka 'big M' logs) or from a preprocessed statistics file.
 
 For cumulative reports, each line in the profile indicates information
-about a Zope method (URL) collected via the detailed request log (the -M log).
+about a Zope method (URL) collected via a detailed request log.
 
 For detailed reports, each line in the profile indicates information about
 a single request.
 
-'filename' is the path to the '-M' log that contains detailed request data.
+For timed reports, each line in the profile indicates informations about
+the number of requests and the number of requests/second for a period of time.
+
+For urlfocus reports, ad-hoc information about requests surrounding the
+specified url is given.
+
+Each 'filename' is a path to a '-M' log that contains detailed request data.
+Multiple input files can be analyzed at the same time by providing the path
+to each file.  (Analyzing  multiple big M log files at once is useful if you
+have more than one Zope client on a single machine and you'd like to
+get an overview of all Zope activity on that machine).
+
+If you wish to make multiple analysis runs against the same input data, you
+may want to use the --writestats option.  The --writestats option creates a
+file which holds preprocessed data representing the specfified input files.
+Subsequent runs (for example with a different sort spec) will be much
+faster if the  --readstats option is used to specify a preprocessed stats
+file instead of actual input files because the logfile parse step is skipped.
 
 If a 'sort' value is specified, sort the profile info by the spec.  The sort
 order is descending unless indicated.    The default cumulative sort spec is
@@ -450,8 +587,7 @@ For detailed (non-cumulative) reports, the following sort specs are accepted:
   'active'      -- total num of requests pending at the end of this request
   'url'         -- the URL/method name (ascending)
 
-  NOTE:  'active' count may be fooled by Zope restarts, which aren't
-  reflected in the -M log.
+For timed and urlfocus reports, there are no sort specs allowed.
 
 If the 'top' argument is specified, only report on the top 'n' entries in
 the profile (as per the sort). The default is to show all data in the profile.
@@ -460,12 +596,23 @@ If the 'verbose' argument is specified, do not trim url to fit into 80 cols.
 
 If the 'today' argument is specified, limit results to hits received today.
 
-If the 'start' argument is specified in the form 'YYYY/MM/DD HH:MM:SS' (UTC),
+The 'resolution' argument is used only for timed reports and specifies the
+number of seconds between consecutive lines in the report 
+(default is 60 seconds).
+
+The 'urlfocustime' argument is used only for urlfocus reports and specifies the
+number of seconds to target before and after the URL provided in urlfocus mode.
+(default is 10 seconds).
+
+If the 'start' argument is specified in the form 'DD/MM/YYYY HH:MM:SS' (UTC),
 limit results to hits received after this date/time.
 
-If the 'end' argument is specified in the form 'YYYY/MM/DD HH:MM:SS' (UTC),
+If the 'end' argument is specified in the form 'DD/MM/YYYY HH:MM:SS' (UTC),
 limit results to hits received before this date/time.
 
+'start' and 'end' arguments are not honored when request stats are obtained
+via the --readstats argument.
+
 Examples:
 
   %(pname)s debug.log
@@ -477,11 +624,22 @@ Examples:
 
     Show detailed report statistics sorted by 'start' (by default).
 
+  %(pname)s debug.log debug2.log --detailed
+
+    Show detailed report statistics for both logs sorted by 'start'
+    (by default).
+
   %(pname)s debug.log --cumulative --sort=mean --today --verbose
 
     Show cumulative report statistics sorted by mean for entries in the log
     which happened today, and do not trim the URL in the resulting report.
 
+  %(pname)s debug.log --urlfocus='/manage_main' --urlfocustime=60
+
+    Show 'urlfocus' report which displays statistics about requests
+    surrounding the invocation of '/manage_main'.  Focus on the time periods
+    60 seconds before and after each invocation of the '/manage_main' URL.
+    
   %(pname)s debug.log --detailed --start='2001/05/10 06:00:00'
     --end='2001/05/11 23:00:00'
 
@@ -489,23 +647,43 @@ Examples:
     begin after 6am UTC on May 10, 2001 and which end before
     11pm UTC on May 11, 2001.
 
+  %(pname)s debug.log --timed --resolution=300 --start='2001/05/10 06:00:00'
+    --end='2001/05/11 23:00:00'
+
+    Show timed report statistics for entries in the log for one day
+    with a resolution of 5 minutes
+
   %(pname)s debug.log --top=100 --sort=max
 
     Show cumulative report of the the 'top' 100 methods sorted by maximum
-    elapsed time.""" % {'pname':pname}
+    elapsed time.
+
+  %(pname)s debug.log debug2.log --writestats='requests.stat'
+
+    Write stats file for debug.log and debug2.log into 'requests.stat' and
+    show default report.
+
+  %(pname)s --readstats='requests.stat' --detailed
+
+    Read from 'requests.stat' stats file (instead of actual -M log files)
+    and show detailed report against this data.""" % {'pname':pname}
     return details
 
 def usage(basic=1):
     usage = (
         """
-Usage: %s filename [--cumulative|--detailed]
-                   [--sort=spec]
-                   [--top==n]
-                   [--verbose]
-                   [ --today | [--start=date] [--end=date] ]
-                   [--help]
+Usage: %s filename1 [filename2 ...]
+          [--cumulative | --detailed | [--timed --resolution=seconds]]
+          [--sort=spec]
+          [--top=n]
+          [--verbose]
+          [--today | [--start=date] [--end=date] ]
+          [--writestats=filename | --readstats=filename]
+          [--urlfocus=url]
+          [--urlfocustime=seconds]
+          [--help]
         
-Provides a profile of the detailed (-M) Zope request log.
+Provides a profile of one or more Zope "-M" request log files.
 """ % sys.argv[0]
         )
     if basic == 1:
@@ -526,18 +704,42 @@ if __name__ == '__main__':
     verbose = 0
     start = None
     end = None
+    resolution=60
+    urlfocustime=10
+    urlfocusurl=None
+    statsfname = None
+    readstats = 0
+    writestats = 0
+    
+    files = []
+    i = 1
+    for arg in sys.argv[1:]:
+        if arg[:2] != '--':
+            files.append(open(arg))
+            sys.argv.remove(arg)
+            i = i + 1
+
     try:
         opts, extra = getopt.getopt(
-            sys.argv[2:], '', ['sort=', 'top=', 'help', 'verbose', 'today',
-                               'cumulative', 'detailed', 'start=',
-                               'end=']
+            sys.argv[1:], '', ['sort=', 'top=', 'help', 'verbose', 'today',
+                               'cumulative', 'detailed', 'timed','start=',
+                               'end=','resolution=', 'writestats=',
+                               'readstats=','urlfocus=','urlfocustime=']
             )
         for opt, val in opts:
+            if opt=='--readstats':
+                statsfname = val
+                readstats = 1
+            elif opt=='--writestats':
+                statsfname = val
+                writestats = 1
             if opt=='--sort': sortby = val
             if opt=='--top': top=int(val)
             if opt=='--help': print detailedusage(); sys.exit(0)
             if opt=='--verbose':
                 verbose = 1
+            if opt=='--resolution':
+                resolution=int(val)
             if opt=='--today':
                 now = time.gmtime(time.time())
                 # for testing - now = (2001, 04, 19, 0, 0, 0, 0, 0, -1)
@@ -556,6 +758,13 @@ if __name__ == '__main__':
                 d_sortby = sortby
             if opt=='--cumulative':
                 mode='cumulative'
+            if opt=='--timed':
+                mode='timed'
+            if opt=='--urlfocus':
+                mode='urlfocus'
+                urlfocusurl = val
+            if opt=='--urlfocustime':
+                urlfocustime=int(val)
 
         validcumsorts = ['url', 'hits', 'hangs', 'max', 'min', 'median',
                          'mean', 'total']
@@ -579,10 +788,16 @@ if __name__ == '__main__':
                 sortf = codesort
             else:
                 sortf = Sort(sortby)
+        elif mode=='timed':
+            sortf = None
+        elif mode=='urlfocus':
+            sortf = Sort('start', ascending=1)
         else:
             raise 'Invalid mode'
-        
-        analyze(open(sys.argv[1]), top, sortf, start, end, mode)
+
+        req=get_requests(files, start, end, statsfname, writestats, readstats)
+        analyze(req, top, sortf, start, end, mode, resolution, urlfocusurl,
+                urlfocustime)
 
     except AssertionError, val:
         a = "%s is not a valid %s sort spec, use one of %s"
@@ -601,10 +816,3 @@ if __name__ == '__main__':
         traceback.print_exc()
         print usage()
         sys.exit(0)
-
-
-
-
-
-
-
